from typing import Any
from typing import Callable
from typing import Optional
from typing import overload

from gi.repository import Gio
from gi.repository import GLib
from gi.repository import GObject

SessionCallbackU = Callable[[Session, Message, Any], None]
SessionCallback = Callable[[Session, Message], None]

ADDRESS_ANY_PORT = ...
ADDRESS_FAMILY: str = ...
ADDRESS_NAME: str = ...
ADDRESS_PHYSICAL: str = ...
ADDRESS_PORT: str = ...
ADDRESS_PROTOCOL: str = ...
ADDRESS_SOCKADDR: str = ...
AUTH_DOMAIN_ADD_PATH: str = ...
AUTH_DOMAIN_BASIC_AUTH_CALLBACK: str = ...
AUTH_DOMAIN_BASIC_AUTH_DATA: str = ...
AUTH_DOMAIN_DIGEST_AUTH_CALLBACK: str = ...
AUTH_DOMAIN_DIGEST_AUTH_DATA: str = ...
AUTH_DOMAIN_FILTER: str = ...
AUTH_DOMAIN_FILTER_DATA: str = ...
AUTH_DOMAIN_GENERIC_AUTH_CALLBACK: str = ...
AUTH_DOMAIN_GENERIC_AUTH_DATA: str = ...
AUTH_DOMAIN_PROXY: str = ...
AUTH_DOMAIN_REALM: str = ...
AUTH_DOMAIN_REMOVE_PATH: str = ...
AUTH_HOST: str = ...
AUTH_IS_AUTHENTICATED: str = ...
AUTH_IS_FOR_PROXY: str = ...
AUTH_REALM: str = ...
AUTH_SCHEME_NAME: str = ...
CHAR_HTTP_CTL: int = ...
CHAR_HTTP_SEPARATOR: int = ...
CHAR_URI_GEN_DELIMS: int = ...
CHAR_URI_PERCENT_ENCODED: int = ...
CHAR_URI_SUB_DELIMS: int = ...
COOKIE_JAR_ACCEPT_POLICY: str = ...
COOKIE_JAR_DB_FILENAME: str = ...
COOKIE_JAR_READ_ONLY: str = ...
COOKIE_JAR_TEXT_FILENAME: str = ...
COOKIE_MAX_AGE_ONE_DAY = ...
COOKIE_MAX_AGE_ONE_HOUR: int = ...
COOKIE_MAX_AGE_ONE_WEEK = ...
COOKIE_MAX_AGE_ONE_YEAR = ...
FORM_MIME_TYPE_MULTIPART: str = ...
FORM_MIME_TYPE_URLENCODED: str = ...
HSTS_ENFORCER_DB_FILENAME: str = ...
HSTS_POLICY_MAX_AGE_PAST = ...
LOGGER_LEVEL: str = ...
LOGGER_MAX_BODY_SIZE: str = ...
MAJOR_VERSION: int = ...
MESSAGE_FIRST_PARTY: str = ...
MESSAGE_FLAGS: str = ...
MESSAGE_HTTP_VERSION: str = ...
MESSAGE_IS_TOP_LEVEL_NAVIGATION: str = ...
MESSAGE_METHOD: str = ...
MESSAGE_PRIORITY: str = ...
MESSAGE_REASON_PHRASE: str = ...
MESSAGE_REQUEST_BODY: str = ...
MESSAGE_REQUEST_BODY_DATA: str = ...
MESSAGE_REQUEST_HEADERS: str = ...
MESSAGE_RESPONSE_BODY: str = ...
MESSAGE_RESPONSE_BODY_DATA: str = ...
MESSAGE_RESPONSE_HEADERS: str = ...
MESSAGE_SERVER_SIDE: str = ...
MESSAGE_SITE_FOR_COOKIES: str = ...
MESSAGE_STATUS_CODE: str = ...
MESSAGE_TLS_CERTIFICATE: str = ...
MESSAGE_TLS_ERRORS: str = ...
MESSAGE_URI: str = ...
MICRO_VERSION = ...
MINOR_VERSION: int = ...
REQUEST_SESSION: str = ...
REQUEST_URI: str = ...
SERVER_ASYNC_CONTEXT: str = ...
SERVER_HTTPS_ALIASES: str = ...
SERVER_HTTP_ALIASES: str = ...
SERVER_INTERFACE: str = ...
SERVER_PORT: str = ...
SERVER_RAW_PATHS: str = ...
SERVER_SERVER_HEADER: str = ...
SERVER_SSL_CERT_FILE: str = ...
SERVER_SSL_KEY_FILE: str = ...
SERVER_TLS_CERTIFICATE: str = ...
SESSION_ACCEPT_LANGUAGE: str = ...
SESSION_ACCEPT_LANGUAGE_AUTO: str = ...
SESSION_ASYNC_CONTEXT: str = ...
SESSION_HTTPS_ALIASES: str = ...
SESSION_HTTP_ALIASES: str = ...
SESSION_IDLE_TIMEOUT: str = ...
SESSION_LOCAL_ADDRESS: str = ...
SESSION_MAX_CONNS: str = ...
SESSION_MAX_CONNS_PER_HOST: str = ...
SESSION_PROXY_RESOLVER: str = ...
SESSION_PROXY_URI: str = ...
SESSION_SSL_CA_FILE: str = ...
SESSION_SSL_STRICT: str = ...
SESSION_SSL_USE_SYSTEM_CA_FILE: str = ...
SESSION_TIMEOUT: str = ...
SESSION_TLS_DATABASE: str = ...
SESSION_TLS_INTERACTION: str = ...
SESSION_USER_AGENT: str = ...
SESSION_USE_NTLM: str = ...
SESSION_USE_THREAD_CONTEXT: str = ...
SOCKET_ASYNC_CONTEXT: str = ...
SOCKET_FLAG_NONBLOCKING: str = ...
SOCKET_IS_SERVER: str = ...
SOCKET_LOCAL_ADDRESS: str = ...
SOCKET_REMOTE_ADDRESS: str = ...
SOCKET_SSL_CREDENTIALS: str = ...
SOCKET_SSL_FALLBACK: str = ...
SOCKET_SSL_STRICT: str = ...
SOCKET_TIMEOUT: str = ...
SOCKET_TLS_CERTIFICATE: str = ...
SOCKET_TLS_ERRORS: str = ...
SOCKET_TRUSTED_CERTIFICATE: str = ...
SOCKET_USE_THREAD_CONTEXT: str = ...
VERSION_MIN_REQUIRED: int = ...
_namespace: str = ...
_version: str = ...

def check_version(*args, **kwargs): ...
def cookie_parse(*args, **kwargs): ...
def cookies_from_request(*args, **kwargs): ...
def cookies_from_response(*args, **kwargs): ...
def cookies_to_cookie_header(*args, **kwargs): ...
def cookies_to_request(*args, **kwargs): ...
def cookies_to_response(*args, **kwargs): ...
def form_decode(*args, **kwargs): ...
def form_decode_multipart(*args, **kwargs): ...
def form_encode_datalist(*args, **kwargs): ...
def form_encode_hash(*args, **kwargs): ...
def form_request_new_from_datalist(*args, **kwargs): ...
def form_request_new_from_hash(*args, **kwargs): ...
def form_request_new_from_multipart(*args, **kwargs): ...
def get_major_version(*args, **kwargs): ...
def get_micro_version(*args, **kwargs): ...
def get_minor_version(*args, **kwargs): ...
def get_resource(*args, **kwargs): ...
def header_contains(*args, **kwargs): ...
def header_free_param_list(*args, **kwargs): ...
def header_g_string_append_param(*args, **kwargs): ...
def header_g_string_append_param_quoted(*args, **kwargs): ...
def header_parse_list(*args, **kwargs): ...
def header_parse_param_list(*args, **kwargs): ...
def header_parse_param_list_strict(*args, **kwargs): ...
def header_parse_quality_list(*args, **kwargs): ...
def header_parse_semi_param_list(*args, **kwargs): ...
def header_parse_semi_param_list_strict(*args, **kwargs): ...
def headers_parse(*args, **kwargs): ...
def headers_parse_request(*args, **kwargs): ...
def headers_parse_response(*args, **kwargs): ...
def headers_parse_status_line(*args, **kwargs): ...
def http_error_quark(*args, **kwargs): ...
def message_headers_iter_init(*args, **kwargs): ...
def request_error_quark(*args, **kwargs): ...
def requester_error_quark(*args, **kwargs): ...
def status_get_phrase(status_code: int) -> str: ...
def status_proxify(status_code: int) -> int: ...
def str_case_equal(*args, **kwargs): ...
def str_case_hash(*args, **kwargs): ...
def tld_domain_is_public_suffix(*args, **kwargs): ...
def tld_error_quark(*args, **kwargs): ...
def tld_get_base_domain(*args, **kwargs): ...
def uri_decode(*args, **kwargs): ...
def uri_encode(*args, **kwargs): ...
def uri_normalize(*args, **kwargs): ...
def value_array_new(*args, **kwargs): ...
def value_hash_insert_value(*args, **kwargs): ...
def value_hash_new(*args, **kwargs): ...
def websocket_client_prepare_handshake(*args, **kwargs): ...
def websocket_client_prepare_handshake_with_extensions(*args, **kwargs): ...
def websocket_client_verify_handshake(*args, **kwargs): ...
def websocket_client_verify_handshake_with_extensions(*args, **kwargs): ...
def websocket_error_get_quark(*args, **kwargs): ...
def websocket_server_check_handshake(*args, **kwargs): ...
def websocket_server_check_handshake_with_extensions(*args, **kwargs): ...
def websocket_server_process_handshake(*args, **kwargs): ...
def websocket_server_process_handshake_with_extensions(*args, **kwargs): ...
def xmlrpc_build_method_call(*args, **kwargs): ...
def xmlrpc_build_method_response(*args, **kwargs): ...
def xmlrpc_build_request(*args, **kwargs): ...
def xmlrpc_build_response(*args, **kwargs): ...
def xmlrpc_error_quark(*args, **kwargs): ...
def xmlrpc_fault_quark(*args, **kwargs): ...
def xmlrpc_message_new(*args, **kwargs): ...
def xmlrpc_message_set_response(*args, **kwargs): ...
def xmlrpc_parse_method_call(*args, **kwargs): ...
def xmlrpc_parse_method_response(*args, **kwargs): ...
def xmlrpc_parse_request(*args, **kwargs): ...
def xmlrpc_parse_response(*args, **kwargs): ...
def xmlrpc_variant_get_datetime(*args, **kwargs): ...
def xmlrpc_variant_new_datetime(*args, **kwargs): ...

class Address:
    parent = ...

    def equal_by_ip(*args, **kwargs): ...
    def equal_by_name(*args, **kwargs): ...
    def get_gsockaddr(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_physical(*args, **kwargs): ...
    def get_port(*args, **kwargs): ...
    def get_sockaddr(*args, **kwargs): ...
    def hash_by_ip(*args, **kwargs): ...
    def hash_by_name(*args, **kwargs): ...
    def is_resolved(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_any(*args, **kwargs): ...
    def new_from_sockaddr(*args, **kwargs): ...
    def resolve_async(*args, **kwargs): ...
    def resolve_sync(*args, **kwargs): ...

class Auth:
    parent = ...
    realm = ...

    def authenticate(*args, **kwargs): ...
    def can_authenticate(*args, **kwargs): ...
    def get_authorization(*args, **kwargs): ...
    def get_host(*args, **kwargs): ...
    def get_info(*args, **kwargs): ...
    def get_protection_space(*args, **kwargs): ...
    def get_realm(*args, **kwargs): ...
    def get_saved_password(*args, **kwargs): ...
    def get_saved_users(*args, **kwargs): ...
    def get_scheme_name(*args, **kwargs): ...
    def has_saved_password(*args, **kwargs): ...
    def is_authenticated(*args, **kwargs): ...
    def is_for_proxy(*args, **kwargs): ...
    def is_ready(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def save_password(*args, **kwargs): ...
    def update(*args, **kwargs): ...
    def do_authenticate(self, *args, **kwargs): ...
    def do_can_authenticate(self, *args, **kwargs): ...
    def do_get_authorization(self, *args, **kwargs): ...
    def do_get_protection_space(self, *args, **kwargs): ...
    def do_is_authenticated(self, *args, **kwargs): ...
    def do_is_ready(self, *args, **kwargs): ...
    def do_update(self, *args, **kwargs): ...

class AuthBasic: ...
class AuthDigest: ...

class AuthDomain:
    parent = ...

    def accepts(*args, **kwargs): ...
    def add_path(*args, **kwargs): ...
    def challenge(*args, **kwargs): ...
    def check_password(*args, **kwargs): ...
    def covers(*args, **kwargs): ...
    def get_realm(*args, **kwargs): ...
    def remove_path(*args, **kwargs): ...
    def set_filter(*args, **kwargs): ...
    def set_generic_auth_callback(*args, **kwargs): ...
    def try_generic_auth_callback(*args, **kwargs): ...
    def do_accepts(self, *args, **kwargs): ...
    def do_challenge(self, *args, **kwargs): ...
    def do_check_password(self, *args, **kwargs): ...

class AuthDomainBasic:
    def set_auth_callback(*args, **kwargs): ...

class AuthDomainDigest:
    def encode_password(*args, **kwargs): ...
    def set_auth_callback(*args, **kwargs): ...

class AuthManager:
    parent = ...
    priv = ...

    def clear_cached_credentials(*args, **kwargs): ...
    def use_auth(*args, **kwargs): ...
    def do_authenticate(self, *args, **kwargs): ...

class AuthNTLM: ...

class AuthNegotiate:
    def supported(*args, **kwargs): ...

class Buffer:
    data = ...
    length = ...

    def free(*args, **kwargs): ...
    def get_as_bytes(*args, **kwargs): ...
    def get_data(self) -> bytes: ...
    def get_owner(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_subbuffer(*args, **kwargs): ...
    def new_with_owner(*args, **kwargs): ...

class ByteArray: ...

class Cache:
    parent_instance = ...
    priv = ...

    def clear(*args, **kwargs): ...
    def dump(*args, **kwargs): ...
    def flush(*args, **kwargs): ...
    def get_max_size(*args, **kwargs): ...
    def load(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_max_size(*args, **kwargs): ...
    def do_get_cacheability(self, *args, **kwargs): ...

class ClientContext:
    def get_address(*args, **kwargs): ...
    def get_auth_domain(*args, **kwargs): ...
    def get_auth_user(*args, **kwargs): ...
    def get_gsocket(*args, **kwargs): ...
    def get_host(*args, **kwargs): ...
    def get_local_address(*args, **kwargs): ...
    def get_remote_address(*args, **kwargs): ...
    def get_socket(*args, **kwargs): ...
    def steal_connection(*args, **kwargs): ...

class Connection: ...

class ContentDecoder:
    parent = ...
    priv = ...

class ContentSniffer(GObject.Object, SessionFeature):
    parent = ...
    priv = ...

    def get_buffer_size(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def sniff(*args, **kwargs): ...
    def do_get_buffer_size(self, *args, **kwargs): ...
    def do_sniff(self, *args, **kwargs): ...

class Cookie:
    domain = ...
    expires = ...
    http_only = ...
    name = ...
    path = ...
    secure = ...
    value = ...

    def applies_to_uri(*args, **kwargs): ...
    def domain_matches(*args, **kwargs): ...
    def equal(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get_domain(*args, **kwargs): ...
    def get_expires(*args, **kwargs): ...
    def get_http_only(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_path(*args, **kwargs): ...
    def get_same_site_policy(*args, **kwargs): ...
    def get_secure(*args, **kwargs): ...
    def get_value(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def parse(*args, **kwargs): ...
    def set_domain(*args, **kwargs): ...
    def set_expires(*args, **kwargs): ...
    def set_http_only(*args, **kwargs): ...
    def set_max_age(*args, **kwargs): ...
    def set_name(*args, **kwargs): ...
    def set_path(*args, **kwargs): ...
    def set_same_site_policy(*args, **kwargs): ...
    def set_secure(*args, **kwargs): ...
    def set_value(*args, **kwargs): ...
    def to_cookie_header(*args, **kwargs): ...
    def to_set_cookie_header(*args, **kwargs): ...

class CookieJar:
    parent = ...

    def add_cookie(*args, **kwargs): ...
    def add_cookie_full(*args, **kwargs): ...
    def add_cookie_with_first_party(*args, **kwargs): ...
    def all_cookies(*args, **kwargs): ...
    def delete_cookie(*args, **kwargs): ...
    def get_accept_policy(*args, **kwargs): ...
    def get_cookie_list(*args, **kwargs): ...
    def get_cookie_list_with_same_site_info(*args, **kwargs): ...
    def get_cookies(*args, **kwargs): ...
    def is_persistent(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def save(*args, **kwargs): ...
    def set_accept_policy(*args, **kwargs): ...
    def set_cookie(*args, **kwargs): ...
    def set_cookie_with_first_party(*args, **kwargs): ...
    def do_changed(self, *args, **kwargs): ...
    def do_is_persistent(self, *args, **kwargs): ...
    def do_save(self, *args, **kwargs): ...

class CookieJarDB: ...
class CookieJarText: ...

class Date:
    day = ...
    hour = ...
    minute = ...
    month = ...
    offset = ...
    second = ...
    utc = ...
    year = ...

    def free(*args, **kwargs): ...
    def get_day(*args, **kwargs): ...
    def get_hour(*args, **kwargs): ...
    def get_minute(*args, **kwargs): ...
    def get_month(*args, **kwargs): ...
    def get_offset(*args, **kwargs): ...
    def get_second(*args, **kwargs): ...
    def get_utc(*args, **kwargs): ...
    def get_year(*args, **kwargs): ...
    def is_past(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_from_now(*args, **kwargs): ...
    def new_from_string(*args, **kwargs): ...
    def new_from_time_t(*args, **kwargs): ...
    def to_string(*args, **kwargs): ...
    def to_time_t(*args, **kwargs): ...
    def to_timeval(*args, **kwargs): ...

class HSTSEnforcer:
    parent = ...
    priv = ...

    def get_domains(*args, **kwargs): ...
    def get_policies(*args, **kwargs): ...
    def has_valid_policy(*args, **kwargs): ...
    def is_persistent(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_policy(*args, **kwargs): ...
    def set_session_policy(*args, **kwargs): ...
    def do_changed(self, *args, **kwargs): ...
    def do_has_valid_policy(self, *args, **kwargs): ...
    def do_hsts_enforced(self, *args, **kwargs): ...
    def do_is_persistent(self, *args, **kwargs): ...

class HSTSEnforcerDB: ...

class HSTSPolicy:
    domain = ...
    expires = ...
    include_subdomains = ...
    max_age = ...

    def equal(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get_domain(*args, **kwargs): ...
    def includes_subdomains(*args, **kwargs): ...
    def is_expired(*args, **kwargs): ...
    def is_session_policy(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_from_response(*args, **kwargs): ...
    def new_full(*args, **kwargs): ...
    def new_session_policy(*args, **kwargs): ...

class Logger:
    parent = ...

    @classmethod
    def new(cls, level: LoggerLogLevel, max_body_size: int) -> Logger: ...
    def set_printer(*args, **kwargs): ...
    def set_request_filter(*args, **kwargs): ...
    def set_response_filter(*args, **kwargs): ...

class Message(GObject.Object):
    method: Optional[str] = ...
    parent: GObject.Object = ...
    reason_phrase: Optional[str] = ...
    request_body: Optional[MessageBody] = ...
    request_headers: Optional[MessageHeaders] = ...
    response_body: Optional[MessageBody] = ...
    response_headers: Optional[MessageHeaders] = ...
    status_code: int = ...

    class Props:
        reason_phrase: Optional[str] = ...
        request_body: Optional[MessageBody] = ...
        request_body_data: Optional[GLib.Bytes] = ...
        request_headers: Optional[MessageHeaders] = ...
        response_body: Optional[MessageBody] = ...
        response_body_data: Optional[GLib.Bytes] = ...
        response_headers: Optional[MessageHeaders] = ...
        status_code: int = ...
        uri: Optional[URI] = ...

    props: Props

    def content_sniffed(*args, **kwargs): ...
    def disable_feature(*args, **kwargs): ...
    def finished(*args, **kwargs): ...
    def get_address(*args, **kwargs): ...
    def get_first_party(*args, **kwargs): ...
    def get_flags(*args, **kwargs): ...
    def get_http_version(*args, **kwargs): ...
    def get_https_status(
        self,
    ) -> tuple[bool, Gio.TlsCertificate, Gio.TlsCertificateFlags]: ...
    def get_is_top_level_navigation(*args, **kwargs): ...
    def get_priority(*args, **kwargs): ...
    def get_site_for_cookies(*args, **kwargs): ...
    def get_soup_request(*args, **kwargs): ...
    def get_uri(*args, **kwargs): ...
    def got_body(*args, **kwargs): ...
    def got_chunk(*args, **kwargs): ...
    def got_headers(*args, **kwargs): ...
    def got_informational(*args, **kwargs): ...
    def is_feature_disabled(*args, **kwargs): ...
    def is_keepalive(*args, **kwargs): ...
    @classmethod
    def new(cls, method: str, uri_string: str) -> Message: ...
    def new_from_uri(*args, **kwargs): ...
    def restarted(*args, **kwargs): ...
    def set_chunk_allocator(*args, **kwargs): ...
    def set_first_party(*args, **kwargs): ...
    def set_flags(self, flags: MessageFlags) -> None: ...
    def set_http_version(*args, **kwargs): ...
    def set_is_top_level_navigation(*args, **kwargs): ...
    def set_priority(*args, **kwargs): ...
    def set_redirect(*args, **kwargs): ...
    def set_request(*args, **kwargs): ...
    def set_response(*args, **kwargs): ...
    def set_site_for_cookies(*args, **kwargs): ...
    def set_status(*args, **kwargs): ...
    def set_status_full(*args, **kwargs): ...
    def set_uri(*args, **kwargs): ...
    def starting(*args, **kwargs): ...
    def wrote_body(*args, **kwargs): ...
    def wrote_body_data(*args, **kwargs): ...
    def wrote_chunk(*args, **kwargs): ...
    def wrote_headers(*args, **kwargs): ...
    def wrote_informational(*args, **kwargs): ...
    def do_finished(self, *args, **kwargs): ...
    def do_got_body(self, *args, **kwargs): ...
    def do_got_chunk(self, *args, **kwargs): ...
    def do_got_headers(self, *args, **kwargs): ...
    def do_got_informational(self, *args, **kwargs): ...
    def do_restarted(self, *args, **kwargs): ...
    def do_starting(self, *args, **kwargs): ...
    def do_wrote_body(self, *args, **kwargs): ...
    def do_wrote_chunk(self, *args, **kwargs): ...
    def do_wrote_headers(self, *args, **kwargs): ...
    def do_wrote_informational(self, *args, **kwargs): ...

class MessageBody:
    data: str = ...
    length: int = ...

    def append(self, data: bytes) -> None: ...
    def append_buffer(*args, **kwargs): ...
    def complete(self) -> None: ...
    def flatten(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get_accumulate(*args, **kwargs): ...
    def get_chunk(*args, **kwargs): ...
    def got_chunk(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_accumulate(self, accumulate: bool) -> None: ...
    def truncate(*args, **kwargs): ...
    def wrote_chunk(*args, **kwargs): ...

class MessageHeaders:
    def append(self, name: str, value: str) -> None: ...
    def clean_connection_headers(*args, **kwargs): ...
    def clear(*args, **kwargs): ...
    def foreach(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def free_ranges(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_content_disposition(*args, **kwargs): ...
    def get_content_length(self) -> int: ...
    def get_content_range(*args, **kwargs): ...
    def get_content_type(*args, **kwargs): ...
    def get_encoding(*args, **kwargs): ...
    def get_expectations(*args, **kwargs): ...
    def get_headers_type(*args, **kwargs): ...
    def get_list(*args, **kwargs): ...
    def get_one(*args, **kwargs): ...
    def get_ranges(*args, **kwargs): ...
    def header_contains(*args, **kwargs): ...
    def header_equals(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def remove(*args, **kwargs): ...
    def replace(*args, **kwargs): ...
    def set_content_disposition(*args, **kwargs): ...
    def set_content_length(self, content_length: int) -> None: ...
    def set_content_range(*args, **kwargs): ...
    def set_content_type(
        self, content_type: str, params: Optional[dict[str, str]]
    ) -> None: ...
    def set_encoding(*args, **kwargs): ...
    def set_expectations(*args, **kwargs): ...
    def set_range(*args, **kwargs): ...
    def set_ranges(*args, **kwargs): ...

class MessageHeadersIter:
    dummy = ...

    def init(*args, **kwargs): ...
    def next(*args, **kwargs): ...

class MessageQueue: ...
class MessageQueueItem: ...

class Multipart:
    def append_form_file(*args, **kwargs): ...
    def append_form_string(*args, **kwargs): ...
    def append_part(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get_length(*args, **kwargs): ...
    def get_part(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_from_message(*args, **kwargs): ...
    def to_message(*args, **kwargs): ...

class MultipartInputStream:
    def get_headers(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def next_part(*args, **kwargs): ...
    def next_part_async(*args, **kwargs): ...
    def next_part_finish(*args, **kwargs): ...

class PasswordManager:
    def get_passwords_async(*args, **kwargs): ...
    def get_passwords_sync(*args, **kwargs): ...

class PasswordManagerInterface:
    base = ...
    get_passwords_async = ...
    get_passwords_sync = ...

class ProxyResolver:
    def get_proxy_async(*args, **kwargs): ...
    def get_proxy_sync(*args, **kwargs): ...

class ProxyResolverDefault:
    parent = ...

class ProxyResolverInterface:
    base = ...
    get_proxy_async = ...
    get_proxy_sync = ...

class ProxyURIResolver:
    def get_proxy_uri_async(*args, **kwargs): ...
    def get_proxy_uri_sync(*args, **kwargs): ...

class ProxyURIResolverInterface:
    _libsoup_reserved1 = ...
    _libsoup_reserved2 = ...
    _libsoup_reserved3 = ...
    _libsoup_reserved4 = ...
    base = ...
    get_proxy_uri_async = ...
    get_proxy_uri_sync = ...

class Range:
    end = ...
    start = ...

class Request:
    parent = ...
    priv = ...

    def get_content_length(self) -> int: ...
    def get_content_type(self) -> Optional[str]: ...
    def get_session(self) -> Session: ...
    def get_uri(self) -> URI: ...
    def send(*args, **kwargs): ...
    def send_async(*args, **kwargs): ...
    def send_finish(*args, **kwargs): ...
    def do_check_uri(self, *args, **kwargs): ...
    def do_get_content_length(self, *args, **kwargs): ...
    def do_get_content_type(self, *args, **kwargs): ...
    def do_send(self, *args, **kwargs): ...
    def do_send_async(self, *args, **kwargs): ...
    def do_send_finish(self, *args, **kwargs): ...

class RequestData: ...

class RequestFile:
    def get_file(*args, **kwargs): ...

class RequestHTTP:
    def get_message(*args, **kwargs): ...

class Requester:
    parent = ...
    priv = ...

    def new(*args, **kwargs): ...
    def request(*args, **kwargs): ...
    def request_uri(*args, **kwargs): ...

class Server:
    parent = ...

    def accept_iostream(*args, **kwargs): ...
    def add_auth_domain(*args, **kwargs): ...
    def add_early_handler(*args, **kwargs): ...
    def add_handler(*args, **kwargs): ...
    def add_websocket_extension(*args, **kwargs): ...
    def add_websocket_handler(*args, **kwargs): ...
    def get_async_context(*args, **kwargs): ...
    def get_listener(*args, **kwargs): ...
    def get_listeners(*args, **kwargs): ...
    def get_port(*args, **kwargs): ...
    def get_uris(*args, **kwargs): ...
    def is_https(*args, **kwargs): ...
    def listen(*args, **kwargs): ...
    def listen_all(*args, **kwargs): ...
    def listen_fd(*args, **kwargs): ...
    def listen_local(*args, **kwargs): ...
    def listen_socket(*args, **kwargs): ...
    def pause_message(*args, **kwargs): ...
    def quit(*args, **kwargs): ...
    def remove_auth_domain(*args, **kwargs): ...
    def remove_handler(*args, **kwargs): ...
    def remove_websocket_extension(*args, **kwargs): ...
    def run(*args, **kwargs): ...
    def run_async(*args, **kwargs): ...
    def set_ssl_cert_file(*args, **kwargs): ...
    def unpause_message(*args, **kwargs): ...
    def do_request_aborted(self, *args, **kwargs): ...
    def do_request_finished(self, *args, **kwargs): ...
    def do_request_read(self, *args, **kwargs): ...
    def do_request_started(self, *args, **kwargs): ...

class Session:
    parent = ...

    class Props:
        https_aliases: list[str] = ...
        proxy_resolver: Optional[Gio.ProxyResolver] = ...
        ssl_strict: bool = ...
        user_agent: str = ...

    props = Props

    def abort(self) -> None: ...
    def add_feature(self, type: Any) -> bool: ...
    def add_feature_by_type(self, feature_type: GObject.GType) -> None: ...
    def cancel_message(self, msg: Message, status_code: int) -> None: ...
    def connect_async(*args, **kwargs): ...
    def connect_finish(*args, **kwargs): ...
    def get_async_context(*args, **kwargs): ...
    def get_feature(*args, **kwargs): ...
    def get_feature_for_message(*args, **kwargs): ...
    def get_features(*args, **kwargs): ...
    def has_feature(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def pause_message(self, msg: Message) -> None: ...
    def prefetch_dns(*args, **kwargs): ...
    def prepare_for_uri(*args, **kwargs): ...
    @overload
    def queue_message(
        self, msg: Message, callback: Optional[SessionCallbackU], *user_data: Any
    ) -> None: ...
    @overload
    def queue_message(
        self, msg: Message, callback: Optional[SessionCallback]
    ) -> None: ...
    def redirect_message(*args, **kwargs): ...
    def remove_feature(*args, **kwargs): ...
    def remove_feature_by_type(*args, **kwargs): ...
    def request(*args, **kwargs): ...
    def request_http(*args, **kwargs): ...
    def request_http_uri(*args, **kwargs): ...
    def request_uri(*args, **kwargs): ...
    def requeue_message(*args, **kwargs): ...
    def send(*args, **kwargs): ...
    def send_async(*args, **kwargs): ...
    def send_finish(*args, **kwargs): ...
    def send_message(*args, **kwargs): ...
    def steal_connection(*args, **kwargs): ...
    def unpause_message(self, msg: Message) -> None: ...
    def websocket_connect_async(
        self,
        msg: Message,
        origin: Optional[str],
        protocols: Optional[list[str]],
        cancellable: Optional[Gio.Cancellable],
        callback: Optional[Gio.AsyncReadyCallback],
        *user_data: Optional[Any],
    ) -> None: ...
    def websocket_connect_finish(
        self, result: Gio.AsyncResult
    ) -> WebsocketConnection: ...
    def would_redirect(*args, **kwargs): ...
    def do_auth_required(self, *args, **kwargs): ...
    def do_authenticate(self, *args, **kwargs): ...
    def do_cancel_message(self, *args, **kwargs): ...
    def do_flush_queue(self, *args, **kwargs): ...
    def do_kick(self, *args, **kwargs): ...
    def do_queue_message(self, *args, **kwargs): ...
    def do_request_started(self, *args, **kwargs): ...
    def do_requeue_message(self, *args, **kwargs): ...
    def do_send_message(self, *args, **kwargs): ...

class SessionAsync: ...

class SessionFeature(GObject.GInterface):
    def add_feature(*args, **kwargs): ...
    def attach(*args, **kwargs): ...
    def detach(*args, **kwargs): ...
    def has_feature(*args, **kwargs): ...
    def remove_feature(*args, **kwargs): ...

class SessionFeatureInterface:
    add_feature = ...
    attach = ...
    detach = ...
    has_feature = ...
    parent = ...
    remove_feature = ...
    request_queued = ...
    request_started = ...
    request_unqueued = ...

class SessionSync: ...

class Socket:
    parent = ...

    def connect_async(*args, **kwargs): ...
    def connect_sync(*args, **kwargs): ...
    def get_fd(*args, **kwargs): ...
    def get_local_address(*args, **kwargs): ...
    def get_remote_address(*args, **kwargs): ...
    def is_connected(*args, **kwargs): ...
    def is_ssl(*args, **kwargs): ...
    def listen(*args, **kwargs): ...
    def read(*args, **kwargs): ...
    def read_until(*args, **kwargs): ...
    def start_proxy_ssl(*args, **kwargs): ...
    def start_ssl(*args, **kwargs): ...
    def write(*args, **kwargs): ...
    def do_disconnected(self, *args, **kwargs): ...
    def do_new_connection(self, *args, **kwargs): ...
    def do_readable(self, *args, **kwargs): ...
    def do_writable(self, *args, **kwargs): ...

class URI:
    fragment = ...
    host = ...
    password = ...
    path = ...
    port = ...
    query = ...
    scheme = ...
    user = ...

    def copy_host(*args, **kwargs): ...
    def decode(*args, **kwargs): ...
    def encode(*args, **kwargs): ...
    def equal(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get_fragment(*args, **kwargs): ...
    def get_host(*args, **kwargs): ...
    def get_password(*args, **kwargs): ...
    def get_path(*args, **kwargs): ...
    def get_port(*args, **kwargs): ...
    def get_query(*args, **kwargs): ...
    def get_scheme(*args, **kwargs): ...
    def get_user(*args, **kwargs): ...
    def host_equal(*args, **kwargs): ...
    def host_hash(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_with_base(*args, **kwargs): ...
    def normalize(*args, **kwargs): ...
    def set_fragment(*args, **kwargs): ...
    def set_host(*args, **kwargs): ...
    def set_password(*args, **kwargs): ...
    def set_path(*args, **kwargs): ...
    def set_port(*args, **kwargs): ...
    def set_query(*args, **kwargs): ...
    def set_query_from_form(*args, **kwargs): ...
    def set_scheme(*args, **kwargs): ...
    def set_user(*args, **kwargs): ...
    def to_string(self, just_path_and_query: bool) -> str: ...
    def uses_default_port(*args, **kwargs): ...

class WebsocketConnection(GObject.Object):
    parent = ...
    pv = ...

    def close(self, code: WebsocketCloseCode, data: Optional[bytes]) -> None: ...
    def get_close_code(*args, **kwargs): ...
    def get_close_data(*args, **kwargs): ...
    def get_connection_type(*args, **kwargs): ...
    def get_extensions(*args, **kwargs): ...
    def get_io_stream(*args, **kwargs): ...
    def get_keepalive_interval(*args, **kwargs): ...
    def get_max_incoming_payload_size(*args, **kwargs): ...
    def get_origin(*args, **kwargs): ...
    def get_protocol(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_uri(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_with_extensions(*args, **kwargs): ...
    def send_binary(self, data: Optional[bytes]) -> None: ...
    def send_message(*args, **kwargs): ...
    def send_text(*args, **kwargs): ...
    def set_keepalive_interval(self, interval: int) -> None: ...
    def set_max_incoming_payload_size(*args, **kwargs): ...
    def do_closed(self, *args, **kwargs): ...
    def do_closing(self, *args, **kwargs): ...
    def do_error(self, *args, **kwargs): ...
    def do_message(self, *args, **kwargs): ...
    def do_pong(self, *args, **kwargs): ...

class WebsocketExtension:
    parent = ...

    def configure(*args, **kwargs): ...
    def get_request_params(*args, **kwargs): ...
    def get_response_params(*args, **kwargs): ...
    def process_incoming_message(*args, **kwargs): ...
    def process_outgoing_message(*args, **kwargs): ...
    def do_configure(self, *args, **kwargs): ...
    def do_get_request_params(self, *args, **kwargs): ...
    def do_get_response_params(self, *args, **kwargs): ...
    def do_process_incoming_message(self, *args, **kwargs): ...
    def do_process_outgoing_message(self, *args, **kwargs): ...

class WebsocketExtensionDeflate: ...

class WebsocketExtensionManager:
    parent = ...

class XMLRPCParams:
    def free(*args, **kwargs): ...
    def parse(*args, **kwargs): ...

class Cacheability(GObject.GFlags):
    CACHEABLE = ...
    UNCACHEABLE = ...
    INVALIDATES = ...
    VALIDATES = ...

class Expectation(GObject.GFlags):
    UNRECOGNIZED = ...
    CONTINUE = ...

class MessageFlags(GObject.GFlags):
    NO_REDIRECT = ...
    CAN_REBUILD = ...
    OVERWRITE_CHUNKS = ...
    CONTENT_DECODED = ...
    CERTIFICATE_TRUSTED = ...
    NEW_CONNECTION = ...
    IDEMPOTENT = ...
    IGNORE_CONNECTION_LIMITS = ...
    DO_NOT_USE_AUTH_CACHE = ...

class ServerListenOptions(GObject.GFlags):
    HTTPS = ...
    IPV4_ONLY = ...
    IPV6_ONLY = ...

class AddressFamily(GObject.GEnum):
    INVALID = ...
    IPV4 = ...
    IPV6 = ...

class CacheResponse(GObject.GEnum):
    FRESH = ...
    NEEDS_VALIDATION = ...
    STALE = ...

class CacheType(GObject.GEnum):
    SINGLE_USER = ...
    SHARED = ...

class ConnectionState(GObject.GEnum):
    NEW = ...
    CONNECTING = ...
    IDLE = ...
    IN_USE = ...
    REMOTE_DISCONNECTED = ...
    DISCONNECTED = ...

class CookieJarAcceptPolicy(GObject.GEnum):
    ALWAYS = ...
    NEVER = ...
    NO_THIRD_PARTY = ...
    GRANDFATHERED_THIRD_PARTY = ...

class DateFormat(GObject.GEnum):
    HTTP = ...
    COOKIE = ...
    RFC2822 = ...
    ISO8601_COMPACT = ...
    ISO8601_FULL = ...
    ISO8601 = ...
    ISO8601_XMLRPC = ...

class Encoding(GObject.GEnum):
    UNRECOGNIZED = ...
    NONE = ...
    CONTENT_LENGTH = ...
    EOF = ...
    CHUNKED = ...
    BYTERANGES = ...

class HTTPVersion(GObject.GEnum):
    HTTP_1_0 = ...
    HTTP_1_1 = ...

class KnownStatusCode(GObject.GEnum):
    NONE = ...
    CANCELLED = ...
    CANT_RESOLVE = ...
    CANT_RESOLVE_PROXY = ...
    CANT_CONNECT = ...
    CANT_CONNECT_PROXY = ...
    SSL_FAILED = ...
    IO_ERROR = ...
    MALFORMED = ...
    TRY_AGAIN = ...
    TOO_MANY_REDIRECTS = ...
    TLS_FAILED = ...
    CONTINUE = ...
    SWITCHING_PROTOCOLS = ...
    PROCESSING = ...
    OK = ...
    CREATED = ...
    ACCEPTED = ...
    NON_AUTHORITATIVE = ...
    NO_CONTENT = ...
    RESET_CONTENT = ...
    PARTIAL_CONTENT = ...
    MULTI_STATUS = ...
    MULTIPLE_CHOICES = ...
    MOVED_PERMANENTLY = ...
    FOUND = ...
    MOVED_TEMPORARILY = ...
    SEE_OTHER = ...
    NOT_MODIFIED = ...
    USE_PROXY = ...
    NOT_APPEARING_IN_THIS_PROTOCOL = ...
    TEMPORARY_REDIRECT = ...
    BAD_REQUEST = ...
    UNAUTHORIZED = ...
    PAYMENT_REQUIRED = ...
    FORBIDDEN = ...
    NOT_FOUND = ...
    METHOD_NOT_ALLOWED = ...
    NOT_ACCEPTABLE = ...
    PROXY_AUTHENTICATION_REQUIRED = ...
    PROXY_UNAUTHORIZED = ...
    REQUEST_TIMEOUT = ...
    CONFLICT = ...
    GONE = ...
    LENGTH_REQUIRED = ...
    PRECONDITION_FAILED = ...
    REQUEST_ENTITY_TOO_LARGE = ...
    REQUEST_URI_TOO_LONG = ...
    UNSUPPORTED_MEDIA_TYPE = ...
    REQUESTED_RANGE_NOT_SATISFIABLE = ...
    INVALID_RANGE = ...
    EXPECTATION_FAILED = ...
    UNPROCESSABLE_ENTITY = ...
    LOCKED = ...
    FAILED_DEPENDENCY = ...
    INTERNAL_SERVER_ERROR = ...
    NOT_IMPLEMENTED = ...
    BAD_GATEWAY = ...
    SERVICE_UNAVAILABLE = ...
    GATEWAY_TIMEOUT = ...
    HTTP_VERSION_NOT_SUPPORTED = ...
    INSUFFICIENT_STORAGE = ...
    NOT_EXTENDED = ...

class LoggerLogLevel(GObject.GEnum):
    NONE = ...
    MINIMAL = ...
    HEADERS = ...
    BODY = ...

class MemoryUse(GObject.GEnum):
    STATIC = ...
    TAKE = ...
    COPY = ...
    TEMPORARY = ...

class MessageHeadersType(GObject.GEnum):
    REQUEST = ...
    RESPONSE = ...
    MULTIPART = ...

class MessagePriority(GObject.GEnum):
    VERY_LOW = ...
    LOW = ...
    NORMAL = ...
    HIGH = ...
    VERY_HIGH = ...

class RequestError(GObject.GEnum):
    BAD_URI = ...
    UNSUPPORTED_URI_SCHEME = ...
    PARSING = ...
    ENCODING = ...
    quark = ...

class RequesterError(GObject.GEnum):
    BAD_URI = ...
    UNSUPPORTED_URI_SCHEME = ...
    quark = ...

class SameSitePolicy(GObject.GEnum):
    NONE = ...
    LAX = ...
    STRICT = ...

class SocketIOStatus(GObject.GEnum):
    OK = ...
    WOULD_BLOCK = ...
    EOF = ...
    ERROR = ...

class Status(GObject.GEnum):
    NONE = ...
    CANCELLED = ...
    CANT_RESOLVE = ...
    CANT_RESOLVE_PROXY = ...
    CANT_CONNECT = ...
    CANT_CONNECT_PROXY = ...
    SSL_FAILED = ...
    IO_ERROR = ...
    MALFORMED = ...
    TRY_AGAIN = ...
    TOO_MANY_REDIRECTS = ...
    TLS_FAILED = ...
    CONTINUE = ...
    SWITCHING_PROTOCOLS = ...
    PROCESSING = ...
    OK = ...
    CREATED = ...
    ACCEPTED = ...
    NON_AUTHORITATIVE = ...
    NO_CONTENT = ...
    RESET_CONTENT = ...
    PARTIAL_CONTENT = ...
    MULTI_STATUS = ...
    MULTIPLE_CHOICES = ...
    MOVED_PERMANENTLY = ...
    FOUND = ...
    MOVED_TEMPORARILY = ...
    SEE_OTHER = ...
    NOT_MODIFIED = ...
    USE_PROXY = ...
    NOT_APPEARING_IN_THIS_PROTOCOL = ...
    TEMPORARY_REDIRECT = ...
    PERMANENT_REDIRECT = ...
    BAD_REQUEST = ...
    UNAUTHORIZED = ...
    PAYMENT_REQUIRED = ...
    FORBIDDEN = ...
    NOT_FOUND = ...
    METHOD_NOT_ALLOWED = ...
    NOT_ACCEPTABLE = ...
    PROXY_AUTHENTICATION_REQUIRED = ...
    PROXY_UNAUTHORIZED = ...
    REQUEST_TIMEOUT = ...
    CONFLICT = ...
    GONE = ...
    LENGTH_REQUIRED = ...
    PRECONDITION_FAILED = ...
    REQUEST_ENTITY_TOO_LARGE = ...
    REQUEST_URI_TOO_LONG = ...
    UNSUPPORTED_MEDIA_TYPE = ...
    REQUESTED_RANGE_NOT_SATISFIABLE = ...
    INVALID_RANGE = ...
    EXPECTATION_FAILED = ...
    UNPROCESSABLE_ENTITY = ...
    LOCKED = ...
    FAILED_DEPENDENCY = ...
    INTERNAL_SERVER_ERROR = ...
    NOT_IMPLEMENTED = ...
    BAD_GATEWAY = ...
    SERVICE_UNAVAILABLE = ...
    GATEWAY_TIMEOUT = ...
    HTTP_VERSION_NOT_SUPPORTED = ...
    INSUFFICIENT_STORAGE = ...
    NOT_EXTENDED = ...
    @classmethod
    def get_phrase(cls, status_code: int) -> str: ...
    @classmethod
    def proxify(cls, status_code: int) -> int: ...

class TLDError(GObject.GEnum):
    INVALID_HOSTNAME = ...
    IS_IP_ADDRESS = ...
    NOT_ENOUGH_DOMAINS = ...
    NO_BASE_DOMAIN = ...
    NO_PSL_DATA = ...
    quark = ...

class WebsocketCloseCode(GObject.GEnum):
    NORMAL = ...
    GOING_AWAY = ...
    PROTOCOL_ERROR = ...
    UNSUPPORTED_DATA = ...
    NO_STATUS = ...
    ABNORMAL = ...
    BAD_DATA = ...
    POLICY_VIOLATION = ...
    TOO_BIG = ...
    NO_EXTENSION = ...
    SERVER_ERROR = ...
    TLS_HANDSHAKE = ...

class WebsocketConnectionType(GObject.GEnum):
    UNKNOWN = ...
    CLIENT = ...
    SERVER = ...

class WebsocketDataType(GObject.GEnum):
    TEXT = ...
    BINARY = ...

class WebsocketError(GObject.GEnum):
    FAILED = ...
    NOT_WEBSOCKET = ...
    BAD_HANDSHAKE = ...
    BAD_ORIGIN = ...
    get_quark = ...

class WebsocketState(GObject.GEnum):
    OPEN = ...
    CLOSING = ...
    CLOSED = ...

class XMLRPCError(GObject.GEnum):
    ARGUMENTS = ...
    RETVAL = ...
    quark = ...

class XMLRPCFault(GObject.GEnum):
    PARSE_ERROR_NOT_WELL_FORMED = ...
    PARSE_ERROR_UNSUPPORTED_ENCODING = ...
    PARSE_ERROR_INVALID_CHARACTER_FOR_ENCODING = ...
    SERVER_ERROR_INVALID_XML_RPC = ...
    SERVER_ERROR_REQUESTED_METHOD_NOT_FOUND = ...
    SERVER_ERROR_INVALID_METHOD_PARAMETERS = ...
    SERVER_ERROR_INTERNAL_XML_RPC_ERROR = ...
    APPLICATION_ERROR = ...
    SYSTEM_ERROR = ...
    TRANSPORT_ERROR = ...
    quark = ...



import typing

from gi.repository import GLib
from gi.repository import GObject
from gi.repository import Gst
from gi.repository import GstSdp
from typing_extensions import Self

T = typing.TypeVar("T")

def webrtc_error_quark() -> int: ...
def webrtc_sdp_type_to_string(type: WebRTCSDPType) -> str: ...

class WebRTCDTLSTransport(Gst.Object):
    """
    :Constructors:

    ::

        WebRTCDTLSTransport(**properties)

    Object GstWebRTCDTLSTransport

    Properties from GstWebRTCDTLSTransport:
      session-id -> guint: Session ID
        Unique session ID
      transport -> GstWebRTCICETransport: ICE transport
        ICE transport used by this dtls transport
      state -> GstWebRTCDTLSTransportState: DTLS state
        State of the DTLS transport
      client -> gboolean: DTLS client
        Are we the client in the DTLS handshake?
      certificate -> gchararray: DTLS certificate
        DTLS certificate
      remote-certificate -> gchararray: Remote DTLS certificate
        Remote DTLS certificate

    Signals from GstObject:
      deep-notify (GstObject, GParam)

    Properties from GstObject:
      name -> gchararray: Name
        The name of the object
      parent -> GstObject: Parent
        The parent of the object

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gst.Object.Props):
        certificate: str
        client: bool
        remote_certificate: str
        session_id: int
        state: WebRTCDTLSTransportState
        transport: WebRTCICETransport
        name: typing.Optional[str]
        parent: typing.Optional[Gst.Object]

    props: Props = ...
    def __init__(
        self,
        *,
        certificate: str = ...,
        client: bool = ...,
        session_id: int = ...,
        name: typing.Optional[str] = ...,
        parent: Gst.Object = ...,
    ) -> None: ...

class WebRTCDTLSTransportClass(GObject.GPointer): ...

class WebRTCDataChannel(GObject.Object):
    """
    :Constructors:

    ::

        WebRTCDataChannel(**properties)

    Object GstWebRTCDataChannel

    Signals from GstWebRTCDataChannel:
      on-open ()
      on-close ()
      on-error (GError)
      on-message-data (GBytes)
      on-message-string (gchararray)
      on-buffered-amount-low ()
      send-data (GBytes)
      send-string (gchararray)
      close ()

    Properties from GstWebRTCDataChannel:
      label -> gchararray: Label
        Data channel label
      ordered -> gboolean: Ordered
        Using ordered transmission mode
      max-packet-lifetime -> gint: Maximum Packet Lifetime
        Maximum number of milliseconds that transmissions and retransmissions may occur in unreliable mode (-1 = unset)
      max-retransmits -> gint: Maximum Retransmits
        Maximum number of retransmissions attempted in unreliable mode
      protocol -> gchararray: Protocol
        Data channel protocol
      negotiated -> gboolean: Negotiated
        Whether this data channel was negotiated by the application
      id -> gint: ID
        ID negotiated by this data channel (-1 = unset)
      priority -> GstWebRTCPriorityType: Priority
        The priority of data sent using this data channel
      ready-state -> GstWebRTCDataChannelState: Ready State
        The Ready state of this data channel
      buffered-amount -> guint64: Buffered Amount
        The amount of data in bytes currently buffered
      buffered-amount-low-threshold -> guint64: Buffered Amount Low Threshold
        The threshold at which the buffered amount is considered low and the buffered-amount-low signal is emitted

    Signals from GObject:
      notify (GParam)
    """
    class Props(GObject.Object.Props):
        buffered_amount: int
        buffered_amount_low_threshold: int
        id: int
        label: str
        max_packet_lifetime: int
        max_retransmits: int
        negotiated: bool
        ordered: bool
        priority: WebRTCPriorityType
        protocol: str
        ready_state: WebRTCDataChannelState

    props: Props = ...
    def __init__(
        self,
        *,
        buffered_amount_low_threshold: int = ...,
        id: int = ...,
        label: str = ...,
        max_packet_lifetime: int = ...,
        max_retransmits: int = ...,
        negotiated: bool = ...,
        ordered: bool = ...,
        priority: WebRTCPriorityType = ...,
        protocol: str = ...,
    ) -> None: ...
    def close(self) -> None: ...
    def send_data(self, data: typing.Optional[GLib.Bytes] = None) -> None: ...
    def send_data_full(self, data: typing.Optional[GLib.Bytes] = None) -> bool: ...
    def send_string(self, str: typing.Optional[str] = None) -> None: ...
    def send_string_full(self, str: typing.Optional[str] = None) -> bool: ...

class WebRTCDataChannelClass(GObject.GPointer): ...

class WebRTCICE(Gst.Object):
    """
    :Constructors:

    ::

        WebRTCICE(**properties)

    Object GstWebRTCICE

    Signals from GstWebRTCICE:
      add-local-ip-address (gchararray) -> gboolean

    Properties from GstWebRTCICE:
      min-rtp-port -> guint: ICE RTP candidate min port
        Minimum port for local rtp port range. min-rtp-port must be <= max-rtp-port
      max-rtp-port -> guint: ICE RTP candidate max port
        Maximum port for local rtp port range. max-rtp-port must be >= min-rtp-port

    Signals from GstObject:
      deep-notify (GstObject, GParam)

    Properties from GstObject:
      name -> gchararray: Name
        The name of the object
      parent -> GstObject: Parent
        The parent of the object

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gst.Object.Props):
        max_rtp_port: int
        min_rtp_port: int
        name: typing.Optional[str]
        parent: typing.Optional[Gst.Object]

    props: Props = ...
    parent: Gst.Object = ...
    ice_gathering_state: WebRTCICEGatheringState = ...
    ice_connection_state: WebRTCICEConnectionState = ...
    min_rtp_port: int = ...
    max_rtp_port: int = ...
    def __init__(
        self,
        *,
        max_rtp_port: int = ...,
        min_rtp_port: int = ...,
        name: typing.Optional[str] = ...,
        parent: Gst.Object = ...,
    ) -> None: ...
    def add_candidate(
        self,
        stream: WebRTCICEStream,
        candidate: str,
        promise: typing.Optional[Gst.Promise] = None,
    ) -> None: ...
    def add_stream(self, session_id: int) -> typing.Optional[WebRTCICEStream]: ...
    def add_turn_server(self, uri: str) -> bool: ...
    def do_add_candidate(
        self,
        stream: WebRTCICEStream,
        candidate: str,
        promise: typing.Optional[Gst.Promise] = None,
    ) -> None: ...
    def do_add_stream(self, session_id: int) -> typing.Optional[WebRTCICEStream]: ...
    def do_add_turn_server(self, uri: str) -> bool: ...
    def do_find_transport(
        self, stream: WebRTCICEStream, component: WebRTCICEComponent
    ) -> typing.Optional[WebRTCICETransport]: ...
    def do_gather_candidates(self, stream: WebRTCICEStream) -> bool: ...
    def do_get_http_proxy(self) -> str: ...
    def do_get_is_controller(self) -> bool: ...
    def do_get_local_candidates(
        self, stream: WebRTCICEStream
    ) -> WebRTCICECandidateStats: ...
    def do_get_remote_candidates(
        self, stream: WebRTCICEStream
    ) -> WebRTCICECandidateStats: ...
    def do_get_selected_pair(
        self, stream: WebRTCICEStream
    ) -> typing.Tuple[bool, WebRTCICECandidateStats, WebRTCICECandidateStats]: ...
    def do_get_stun_server(self) -> typing.Optional[str]: ...
    def do_get_turn_server(self) -> typing.Optional[str]: ...
    def do_set_force_relay(self, force_relay: bool) -> None: ...
    def do_set_http_proxy(self, uri: str) -> None: ...
    def do_set_is_controller(self, controller: bool) -> None: ...
    def do_set_local_credentials(
        self, stream: WebRTCICEStream, ufrag: str, pwd: str
    ) -> bool: ...
    def do_set_on_ice_candidate(
        self, func: typing.Callable[..., None], *user_data: typing.Any
    ) -> None: ...
    def do_set_remote_credentials(
        self, stream: WebRTCICEStream, ufrag: str, pwd: str
    ) -> bool: ...
    def do_set_stun_server(self, uri: typing.Optional[str] = None) -> None: ...
    def do_set_tos(self, stream: WebRTCICEStream, tos: int) -> None: ...
    def do_set_turn_server(self, uri: typing.Optional[str] = None) -> None: ...
    def find_transport(
        self, stream: WebRTCICEStream, component: WebRTCICEComponent
    ) -> typing.Optional[WebRTCICETransport]: ...
    def gather_candidates(self, stream: WebRTCICEStream) -> bool: ...
    def get_http_proxy(self) -> str: ...
    def get_is_controller(self) -> bool: ...
    def get_local_candidates(
        self, stream: WebRTCICEStream
    ) -> list[WebRTCICECandidateStats]: ...
    def get_remote_candidates(
        self, stream: WebRTCICEStream
    ) -> list[WebRTCICECandidateStats]: ...
    def get_selected_pair(
        self, stream: WebRTCICEStream
    ) -> typing.Tuple[bool, WebRTCICECandidateStats, WebRTCICECandidateStats]: ...
    def get_stun_server(self) -> typing.Optional[str]: ...
    def get_turn_server(self) -> typing.Optional[str]: ...
    def set_force_relay(self, force_relay: bool) -> None: ...
    def set_http_proxy(self, uri: str) -> None: ...
    def set_is_controller(self, controller: bool) -> None: ...
    def set_local_credentials(
        self, stream: WebRTCICEStream, ufrag: str, pwd: str
    ) -> bool: ...
    def set_on_ice_candidate(
        self, func: typing.Callable[..., None], *user_data: typing.Any
    ) -> None: ...
    def set_remote_credentials(
        self, stream: WebRTCICEStream, ufrag: str, pwd: str
    ) -> bool: ...
    def set_stun_server(self, uri: typing.Optional[str] = None) -> None: ...
    def set_tos(self, stream: WebRTCICEStream, tos: int) -> None: ...
    def set_turn_server(self, uri: typing.Optional[str] = None) -> None: ...

class WebRTCICECandidateStats(GObject.GBoxed):
    """
    :Constructors:

    ::

        WebRTCICECandidateStats()
    """

    ipaddr: str = ...
    port: int = ...
    stream_id: int = ...
    type: str = ...
    proto: str = ...
    relay_proto: str = ...
    prio: int = ...
    url: str = ...
    def copy(self) -> WebRTCICECandidateStats: ...
    def free(self) -> None: ...

class WebRTCICEClass(GObject.GPointer):
    """
    :Constructors:

    ::

        WebRTCICEClass()
    """

    parent_class: Gst.ObjectClass = ...
    add_stream: typing.Callable[
        [WebRTCICE, int], typing.Optional[WebRTCICEStream]
    ] = ...
    find_transport: typing.Callable[
        [WebRTCICE, WebRTCICEStream, WebRTCICEComponent],
        typing.Optional[WebRTCICETransport],
    ] = ...
    gather_candidates: typing.Callable[[WebRTCICE, WebRTCICEStream], bool] = ...
    add_candidate: typing.Callable[
        [WebRTCICE, WebRTCICEStream, str, typing.Optional[Gst.Promise]], None
    ] = ...
    set_local_credentials: typing.Callable[
        [WebRTCICE, WebRTCICEStream, str, str], bool
    ] = ...
    set_remote_credentials: typing.Callable[
        [WebRTCICE, WebRTCICEStream, str, str], bool
    ] = ...
    add_turn_server: typing.Callable[[WebRTCICE, str], bool] = ...
    set_is_controller: typing.Callable[[WebRTCICE, bool], None] = ...
    get_is_controller: typing.Callable[[WebRTCICE], bool] = ...
    set_force_relay: typing.Callable[[WebRTCICE, bool], None] = ...
    set_stun_server: typing.Callable[[WebRTCICE, typing.Optional[str]], None] = ...
    get_stun_server: typing.Callable[[WebRTCICE], typing.Optional[str]] = ...
    set_turn_server: typing.Callable[[WebRTCICE, typing.Optional[str]], None] = ...
    get_turn_server: typing.Callable[[WebRTCICE], typing.Optional[str]] = ...
    set_http_proxy: typing.Callable[[WebRTCICE, str], None] = ...
    get_http_proxy: typing.Callable[[WebRTCICE], str] = ...
    set_tos: typing.Callable[[WebRTCICE, WebRTCICEStream, int], None] = ...
    set_on_ice_candidate: typing.Callable[..., None] = ...
    get_local_candidates: typing.Callable[
        [WebRTCICE, WebRTCICEStream], WebRTCICECandidateStats
    ] = ...
    get_remote_candidates: typing.Callable[
        [WebRTCICE, WebRTCICEStream], WebRTCICECandidateStats
    ] = ...
    get_selected_pair: typing.Callable[
        [WebRTCICE, WebRTCICEStream],
        typing.Tuple[bool, WebRTCICECandidateStats, WebRTCICECandidateStats],
    ] = ...

class WebRTCICEStream(Gst.Object):
    """
    :Constructors:

    ::

        WebRTCICEStream(**properties)

    Object GstWebRTCICEStream

    Properties from GstWebRTCICEStream:
      stream-id -> guint: ICE stream id
        ICE stream id associated with this stream

    Signals from GstObject:
      deep-notify (GstObject, GParam)

    Properties from GstObject:
      name -> gchararray: Name
        The name of the object
      parent -> GstObject: Parent
        The parent of the object

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gst.Object.Props):
        stream_id: int
        name: typing.Optional[str]
        parent: typing.Optional[Gst.Object]

    props: Props = ...
    parent: Gst.Object = ...
    stream_id: int = ...
    def __init__(
        self,
        *,
        stream_id: int = ...,
        name: typing.Optional[str] = ...,
        parent: Gst.Object = ...,
    ) -> None: ...
    def do_find_transport(
        self, component: WebRTCICEComponent
    ) -> typing.Optional[WebRTCICETransport]: ...
    def do_gather_candidates(self) -> bool: ...
    def find_transport(
        self, component: WebRTCICEComponent
    ) -> typing.Optional[WebRTCICETransport]: ...
    def gather_candidates(self) -> bool: ...

class WebRTCICEStreamClass(GObject.GPointer):
    """
    :Constructors:

    ::

        WebRTCICEStreamClass()
    """

    parent_class: Gst.ObjectClass = ...
    find_transport: typing.Callable[
        [WebRTCICEStream, WebRTCICEComponent], typing.Optional[WebRTCICETransport]
    ] = ...
    gather_candidates: typing.Callable[[WebRTCICEStream], bool] = ...

class WebRTCICETransport(Gst.Object):
    """
    :Constructors:

    ::

        WebRTCICETransport(**properties)

    Object GstWebRTCICETransport

    Signals from GstWebRTCICETransport:
      on-selected-candidate-pair-change ()
      on-new-candidate (gchararray)

    Properties from GstWebRTCICETransport:
      component -> GstWebRTCICEComponent: ICE component
        The ICE component of this transport
      state -> GstWebRTCICEConnectionState: ICE connection state
        The ICE connection state of this transport
      gathering-state -> GstWebRTCICEGatheringState: ICE gathering state
        The ICE gathering state of this transport

    Signals from GstObject:
      deep-notify (GstObject, GParam)

    Properties from GstObject:
      name -> gchararray: Name
        The name of the object
      parent -> GstObject: Parent
        The parent of the object

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gst.Object.Props):
        component: WebRTCICEComponent
        gathering_state: WebRTCICEGatheringState
        state: WebRTCICEConnectionState
        name: typing.Optional[str]
        parent: typing.Optional[Gst.Object]

    props: Props = ...
    parent: Gst.Object = ...
    role: WebRTCICERole = ...
    component: WebRTCICEComponent = ...
    state: WebRTCICEConnectionState = ...
    gathering_state: WebRTCICEGatheringState = ...
    src: Gst.Element = ...
    sink: Gst.Element = ...
    def __init__(
        self,
        *,
        component: WebRTCICEComponent = ...,
        name: typing.Optional[str] = ...,
        parent: Gst.Object = ...,
    ) -> None: ...
    def connection_state_change(self, new_state: WebRTCICEConnectionState) -> None: ...
    def do_gather_candidates(self) -> bool: ...
    def gathering_state_change(self, new_state: WebRTCICEGatheringState) -> None: ...
    def new_candidate(
        self, stream_id: int, component: WebRTCICEComponent, attr: str
    ) -> None: ...
    def selected_pair_change(self) -> None: ...

class WebRTCICETransportClass(GObject.GPointer):
    """
    :Constructors:

    ::

        WebRTCICETransportClass()
    """

    parent_class: Gst.ObjectClass = ...
    gather_candidates: typing.Callable[[WebRTCICETransport], bool] = ...

class WebRTCRTPReceiver(Gst.Object):
    """
    :Constructors:

    ::

        WebRTCRTPReceiver(**properties)

    Object GstWebRTCRTPReceiver

    Properties from GstWebRTCRTPReceiver:
      transport -> GstWebRTCDTLSTransport: Transport
        The DTLS transport for this receiver

    Signals from GstObject:
      deep-notify (GstObject, GParam)

    Properties from GstObject:
      name -> gchararray: Name
        The name of the object
      parent -> GstObject: Parent
        The parent of the object

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gst.Object.Props):
        transport: WebRTCDTLSTransport
        name: typing.Optional[str]
        parent: typing.Optional[Gst.Object]

    props: Props = ...
    def __init__(
        self, *, name: typing.Optional[str] = ..., parent: Gst.Object = ...
    ) -> None: ...

class WebRTCRTPReceiverClass(GObject.GPointer): ...

class WebRTCRTPSender(Gst.Object):
    """
    :Constructors:

    ::

        WebRTCRTPSender(**properties)

    Object GstWebRTCRTPSender

    Properties from GstWebRTCRTPSender:
      priority -> GstWebRTCPriorityType: Priority
        The priority from which to set the DSCP field on packets
      transport -> GstWebRTCDTLSTransport: Transport
        The DTLS transport for this sender

    Signals from GstObject:
      deep-notify (GstObject, GParam)

    Properties from GstObject:
      name -> gchararray: Name
        The name of the object
      parent -> GstObject: Parent
        The parent of the object

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gst.Object.Props):
        priority: WebRTCPriorityType
        transport: WebRTCDTLSTransport
        name: typing.Optional[str]
        parent: typing.Optional[Gst.Object]

    props: Props = ...
    def __init__(
        self,
        *,
        priority: WebRTCPriorityType = ...,
        name: typing.Optional[str] = ...,
        parent: Gst.Object = ...,
    ) -> None: ...
    def set_priority(self, priority: WebRTCPriorityType) -> None: ...

class WebRTCRTPSenderClass(GObject.GPointer): ...

class WebRTCRTPTransceiver(Gst.Object):
    """
    :Constructors:

    ::

        WebRTCRTPTransceiver(**properties)

    Object GstWebRTCRTPTransceiver

    Properties from GstWebRTCRTPTransceiver:
      sender -> GstWebRTCRTPSender: Sender
        The RTP sender for this transceiver
      receiver -> GstWebRTCRTPReceiver: Receiver
        The RTP receiver for this transceiver
      direction -> GstWebRTCRTPTransceiverDirection: Direction
        Transceiver direction
      mlineindex -> guint: Media Line Index
        Index in the SDP of the Media
      mid -> gchararray: Media ID
        The media ID of the m-line associated with this transceiver. This  association is established, when possible, whenever either a local or remote description is applied. This field is null if neither a local or remote description has been applied, or if its associated m-line is rejected by either a remote offer or any answer.
      current-direction -> GstWebRTCRTPTransceiverDirection: Current Direction
        Transceiver current direction
      kind -> GstWebRTCKind: Media Kind
        Kind of media this transceiver transports
      codec-preferences -> GstCaps: Codec Preferences
        Caps representing the codec preferences.

    Signals from GstObject:
      deep-notify (GstObject, GParam)

    Properties from GstObject:
      name -> gchararray: Name
        The name of the object
      parent -> GstObject: Parent
        The parent of the object

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gst.Object.Props):
        codec_preferences: Gst.Caps
        current_direction: WebRTCRTPTransceiverDirection
        direction: WebRTCRTPTransceiverDirection
        kind: WebRTCKind
        mid: str
        mlineindex: int
        receiver: WebRTCRTPReceiver
        sender: WebRTCRTPSender
        name: typing.Optional[str]
        parent: typing.Optional[Gst.Object]

    props: Props = ...
    def __init__(
        self,
        *,
        codec_preferences: Gst.Caps = ...,
        direction: WebRTCRTPTransceiverDirection = ...,
        mlineindex: int = ...,
        receiver: WebRTCRTPReceiver = ...,
        sender: WebRTCRTPSender = ...,
        name: typing.Optional[str] = ...,
        parent: Gst.Object = ...,
    ) -> None: ...

class WebRTCRTPTransceiverClass(GObject.GPointer): ...

class WebRTCSCTPTransport(Gst.Object):
    """
    :Constructors:

    ::

        WebRTCSCTPTransport(**properties)

    Object GstWebRTCSCTPTransport

    Properties from GstWebRTCSCTPTransport:
      transport -> GstWebRTCDTLSTransport: WebRTC DTLS Transport
        DTLS transport used for this SCTP transport
      state -> GstWebRTCSCTPTransportState: WebRTC SCTP Transport state
        WebRTC SCTP Transport state
      max-message-size -> guint64: Maximum message size
        Maximum message size as reported by the transport
      max-channels -> guint: Maximum number of channels
        Maximum number of channels

    Signals from GstObject:
      deep-notify (GstObject, GParam)

    Properties from GstObject:
      name -> gchararray: Name
        The name of the object
      parent -> GstObject: Parent
        The parent of the object

    Signals from GObject:
      notify (GParam)
    """
    class Props(Gst.Object.Props):
        max_channels: int
        max_message_size: int
        state: WebRTCSCTPTransportState
        transport: WebRTCDTLSTransport
        name: typing.Optional[str]
        parent: typing.Optional[Gst.Object]

    props: Props = ...
    def __init__(
        self, *, name: typing.Optional[str] = ..., parent: Gst.Object = ...
    ) -> None: ...

class WebRTCSCTPTransportClass(GObject.GPointer): ...

class WebRTCSessionDescription(GObject.GBoxed):
    """
    :Constructors:

    ::

        WebRTCSessionDescription()
        new(type:GstWebRTC.WebRTCSDPType, sdp:GstSdp.SDPMessage) -> GstWebRTC.WebRTCSessionDescription
    """

    type: WebRTCSDPType = ...
    sdp: GstSdp.SDPMessage = ...
    def copy(self) -> WebRTCSessionDescription: ...
    def free(self) -> None: ...
    @classmethod
    def new(
        cls, type: WebRTCSDPType, sdp: GstSdp.SDPMessage
    ) -> WebRTCSessionDescription: ...

class WebRTCBundlePolicy(GObject.GEnum):
    BALANCED = 1
    MAX_BUNDLE = 3
    MAX_COMPAT = 2
    NONE = 0

class WebRTCDTLSSetup(GObject.GEnum):
    ACTIVE = 2
    ACTPASS = 1
    NONE = 0
    PASSIVE = 3

class WebRTCDTLSTransportState(GObject.GEnum):
    CLOSED = 1
    CONNECTED = 4
    CONNECTING = 3
    FAILED = 2
    NEW = 0

class WebRTCDataChannelState(GObject.GEnum):
    CLOSED = 4
    CLOSING = 3
    CONNECTING = 1
    OPEN = 2

class WebRTCError(GObject.GEnum):
    DATA_CHANNEL_FAILURE = 0
    DTLS_FAILURE = 1
    ENCODER_ERROR = 6
    FINGERPRINT_FAILURE = 2
    HARDWARE_ENCODER_NOT_AVAILABLE = 5
    INTERNAL_FAILURE = 8
    INVALID_MODIFICATION = 9
    INVALID_STATE = 7
    SCTP_FAILURE = 3
    SDP_SYNTAX_ERROR = 4
    TYPE_ERROR = 10
    @staticmethod
    def quark() -> int: ...

class WebRTCFECType(GObject.GEnum):
    NONE = 0
    ULP_RED = 1

class WebRTCICEComponent(GObject.GEnum):
    RTCP = 1
    RTP = 0

class WebRTCICEConnectionState(GObject.GEnum):
    CHECKING = 1
    CLOSED = 6
    COMPLETED = 3
    CONNECTED = 2
    DISCONNECTED = 5
    FAILED = 4
    NEW = 0

class WebRTCICEGatheringState(GObject.GEnum):
    COMPLETE = 2
    GATHERING = 1
    NEW = 0

class WebRTCICERole(GObject.GEnum):
    CONTROLLED = 0
    CONTROLLING = 1

class WebRTCICETransportPolicy(GObject.GEnum):
    ALL = 0
    RELAY = 1

class WebRTCKind(GObject.GEnum):
    AUDIO = 1
    UNKNOWN = 0
    VIDEO = 2

class WebRTCPeerConnectionState(GObject.GEnum):
    CLOSED = 5
    CONNECTED = 2
    CONNECTING = 1
    DISCONNECTED = 3
    FAILED = 4
    NEW = 0

class WebRTCPriorityType(GObject.GEnum):
    HIGH = 4
    LOW = 2
    MEDIUM = 3
    VERY_LOW = 1

class WebRTCRTPTransceiverDirection(GObject.GEnum):
    INACTIVE = 1
    NONE = 0
    RECVONLY = 3
    SENDONLY = 2
    SENDRECV = 4

class WebRTCSCTPTransportState(GObject.GEnum):
    CLOSED = 3
    CONNECTED = 2
    CONNECTING = 1
    NEW = 0

class WebRTCSDPType(GObject.GEnum):
    ANSWER = 3
    OFFER = 1
    PRANSWER = 2
    ROLLBACK = 4
    @staticmethod
    def to_string(type: WebRTCSDPType) -> str: ...

class WebRTCSignalingState(GObject.GEnum):
    CLOSED = 1
    HAVE_LOCAL_OFFER = 2
    HAVE_LOCAL_PRANSWER = 4
    HAVE_REMOTE_OFFER = 3
    HAVE_REMOTE_PRANSWER = 5
    STABLE = 0

class WebRTCStatsType(GObject.GEnum):
    CANDIDATE_PAIR = 11
    CERTIFICATE = 14
    CODEC = 1
    CSRC = 6
    DATA_CHANNEL = 8
    INBOUND_RTP = 2
    LOCAL_CANDIDATE = 12
    OUTBOUND_RTP = 3
    PEER_CONNECTION = 7
    REMOTE_CANDIDATE = 13
    REMOTE_INBOUND_RTP = 4
    REMOTE_OUTBOUND_RTP = 5
    STREAM = 9
    TRANSPORT = 10



from typing import Any
from typing import Callable
from typing import Literal
from typing import Optional
from typing import Sequence
from typing import Tuple
from typing import Type
from typing import TypeVar

from gi.repository import GLib
from gi.repository import GObject

MAJOR_VERSION: int = 2
MICRO_VERSION: int = 3
MINOR_VERSION: int = 42
OPTIONS_USE_DFG: str = "useDFGJIT"
OPTIONS_USE_FTL: str = "useFTLJIT"
OPTIONS_USE_JIT: str = "useJIT"
OPTIONS_USE_LLINT: str = "useLLInt"
_lock = ...  # FIXME Constant
_namespace: str = "JavaScriptCore"
_version: str = "6.0"

def get_major_version() -> int: ...
def get_micro_version() -> int: ...
def get_minor_version() -> int: ...
def options_foreach(function: Callable[..., bool], *user_data: Any) -> None: ...
def options_get_boolean(option: str) -> Tuple[bool, bool]: ...
def options_get_double(option: str) -> Tuple[bool, float]: ...
def options_get_int(option: str) -> Tuple[bool, int]: ...
def options_get_option_group() -> GLib.OptionGroup: ...
def options_get_range_string(option: str) -> Tuple[bool, str]: ...
def options_get_size(option: str) -> Tuple[bool, int]: ...
def options_get_string(option: str) -> Tuple[bool, str]: ...
def options_get_uint(option: str) -> Tuple[bool, int]: ...
def options_set_boolean(option: str, value: bool) -> bool: ...
def options_set_double(option: str, value: float) -> bool: ...
def options_set_int(option: str, value: int) -> bool: ...
def options_set_range_string(option: str, value: str) -> bool: ...
def options_set_size(option: str, value: int) -> bool: ...
def options_set_string(option: str, value: str) -> bool: ...
def options_set_uint(option: str, value: int) -> bool: ...

class Class(GObject.Object):
    """
    :Constructors:

    ::

        Class(**properties)

    Object JSCClass

    Properties from JSCClass:
      context -> JSCContext: context
      name -> gchararray: name
      parent -> JSCClass: parent

    Signals from GObject:
      notify (GParam)
    """

    class Props:
        name: str
        parent: Class
        context: Context

    props: Props = ...
    def __init__(
        self, context: Context = ..., name: str = ..., parent: Class = ...
    ): ...
    def add_constructor(
        self,
        name: Optional[str],
        callback: Callable[..., None],
        return_type: Type,
        parameter_types: Optional[Sequence[Type]] = None,
        *user_data: Any,
    ) -> Value: ...
    def add_constructor_variadic(
        self,
        name: Optional[str],
        callback: Callable[..., None],
        return_type: Type,
        *user_data: Any,
    ) -> Value: ...
    def add_method(
        self,
        name: str,
        callback: Callable[..., None],
        return_type: Type,
        parameter_types: Optional[Sequence[Type]] = None,
        *user_data: Any,
    ) -> None: ...
    def add_method_variadic(
        self,
        name: str,
        callback: Callable[..., None],
        return_type: Type,
        *user_data: Any,
    ) -> None: ...
    def add_property(
        self,
        name: str,
        property_type: Type,
        getter: Optional[Callable[[], None]] = None,
        setter: Optional[Callable[..., None]] = None,
        *user_data: Any,
    ) -> None: ...
    def get_name(self) -> str: ...
    def get_parent(self) -> Class: ...

class ClassClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ClassClass()
    """

    parent_class: GObject.ObjectClass = ...

class ClassVTable(GObject.GPointer):
    """
    :Constructors:

    ::

        ClassVTable()
    """

    get_property: Callable[[Class, Context, None, str], Optional[Value]] = ...
    set_property: Callable[[Class, Context, None, str, Value], bool] = ...
    has_property: Callable[[Class, Context, None, str], bool] = ...
    delete_property: Callable[[Class, Context, None, str], bool] = ...
    enumerate_properties: Callable[[Class, Context, None], Optional[list[str]]] = ...
    _jsc_reserved0: None = ...
    _jsc_reserved1: None = ...
    _jsc_reserved2: None = ...
    _jsc_reserved3: None = ...
    _jsc_reserved4: None = ...
    _jsc_reserved5: None = ...
    _jsc_reserved6: None = ...
    _jsc_reserved7: None = ...

class Context(GObject.Object):
    """
    :Constructors:

    ::

        Context(**properties)
        new() -> JavaScriptCore.Context
        new_with_virtual_machine(vm:JavaScriptCore.VirtualMachine) -> JavaScriptCore.Context

    Object JSCContext

    Properties from JSCContext:
      virtual-machine -> JSCVirtualMachine: virtual-machine

    Signals from GObject:
      notify (GParam)
    """

    class Props:
        virtual_machine: VirtualMachine

    props: Props = ...
    def __init__(self, virtual_machine: VirtualMachine = ...): ...
    def check_syntax(
        self, code: str, length: int, mode: CheckSyntaxMode, uri: str, line_number: int
    ) -> Tuple[CheckSyntaxResult, Exception]: ...
    def clear_exception(self) -> None: ...
    def evaluate(self, code: str, length: int) -> Value: ...
    def evaluate_in_object(
        self,
        code: str,
        length: int,
        object_instance: None,
        object_class: Optional[Class],
        uri: str,
        line_number: int,
    ) -> Tuple[Value, Value]: ...
    def evaluate_with_source_uri(
        self, code: str, length: int, uri: str, line_number: int
    ) -> Value: ...
    @staticmethod
    def get_current() -> Optional[Context]: ...
    def get_exception(self) -> Optional[Exception]: ...
    def get_global_object(self) -> Value: ...
    def get_value(self, name: str) -> Value: ...
    def get_virtual_machine(self) -> VirtualMachine: ...
    @classmethod
    def new(cls) -> Context: ...
    @classmethod
    def new_with_virtual_machine(cls, vm: VirtualMachine) -> Context: ...
    def pop_exception_handler(self) -> None: ...
    def push_exception_handler(
        self, handler: Callable[..., None], *user_data: Any
    ) -> None: ...
    def register_class(
        self,
        name: str,
        parent_class: Optional[Class] = None,
        vtable: Optional[ClassVTable] = None,
        destroy_notify: Optional[Callable[[None], None]] = None,
    ) -> Class: ...
    def set_value(self, name: str, value: Value) -> None: ...
    def throw(self, error_message: str) -> None: ...
    def throw_exception(self, exception: Exception) -> None: ...
    def throw_with_name(self, error_name: str, error_message: str) -> None: ...

class ContextClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ContextClass()
    """

    parent_class: GObject.ObjectClass = ...

class Exception(GObject.Object):
    """
    :Constructors:

    ::

        Exception(**properties)
        new(context:JavaScriptCore.Context, message:str) -> JavaScriptCore.Exception
        new_with_name(context:JavaScriptCore.Context, name:str, message:str) -> JavaScriptCore.Exception

    Object JSCException

    Signals from GObject:
      notify (GParam)
    """

    def get_backtrace_string(self) -> Optional[str]: ...
    def get_column_number(self) -> int: ...
    def get_line_number(self) -> int: ...
    def get_message(self) -> str: ...
    def get_name(self) -> str: ...
    def get_source_uri(self) -> Optional[str]: ...
    @classmethod
    def new(cls, context: Context, message: str) -> Exception: ...
    @classmethod
    def new_with_name(cls, context: Context, name: str, message: str) -> Exception: ...
    def report(self) -> str: ...
    def to_string(self) -> str: ...

class ExceptionClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ExceptionClass()
    """

    parent_class: GObject.ObjectClass = ...

class Value(GObject.Object):
    """
    :Constructors:

    ::

        Value(**properties)
        new_array_buffer(context:JavaScriptCore.Context, data=None, size:int, destroy_notify:GLib.DestroyNotify=None, user_data=None) -> JavaScriptCore.Value or None
        new_array_from_garray(context:JavaScriptCore.Context, array:list=None) -> JavaScriptCore.Value
        new_array_from_strv(context:JavaScriptCore.Context, strv:list) -> JavaScriptCore.Value
        new_boolean(context:JavaScriptCore.Context, value:bool) -> JavaScriptCore.Value
        new_from_json(context:JavaScriptCore.Context, json:str) -> JavaScriptCore.Value
        new_function_variadic(context:JavaScriptCore.Context, name:str=None, callback:GObject.Callback, user_data=None, return_type:GType) -> JavaScriptCore.Value
        new_function(context:JavaScriptCore.Context, name:str=None, callback:GObject.Callback, user_data=None, return_type:GType, parameter_types:list=None) -> JavaScriptCore.Value
        new_null(context:JavaScriptCore.Context) -> JavaScriptCore.Value
        new_number(context:JavaScriptCore.Context, number:float) -> JavaScriptCore.Value
        new_object(context:JavaScriptCore.Context, instance=None, jsc_class:JavaScriptCore.Class=None) -> JavaScriptCore.Value
        new_string(context:JavaScriptCore.Context, string:str=None) -> JavaScriptCore.Value
        new_string_from_bytes(context:JavaScriptCore.Context, bytes:GLib.Bytes=None) -> JavaScriptCore.Value
        new_typed_array(context:JavaScriptCore.Context, type:JavaScriptCore.TypedArrayType, length:int) -> JavaScriptCore.Value
        new_undefined(context:JavaScriptCore.Context) -> JavaScriptCore.Value

    Object JSCValue

    Properties from JSCValue:
      context -> JSCContext: context

    Signals from GObject:
      notify (GParam)
    """

    class Props:
        context: Context

    props: Props = ...
    def __init__(self, context: Context = ...): ...
    def array_buffer_get_data(self, size: Optional[int] = None) -> None: ...
    def array_buffer_get_size(self) -> int: ...
    def constructor_call(
        self, parameters: Optional[Sequence[Value]] = None
    ) -> Value: ...
    def function_call(self, parameters: Optional[Sequence[Value]] = None) -> Value: ...
    def get_context(self) -> Context: ...
    def is_array(self) -> bool: ...
    def is_array_buffer(self) -> bool: ...
    def is_boolean(self) -> bool: ...
    def is_constructor(self) -> bool: ...
    def is_function(self) -> bool: ...
    def is_null(self) -> bool: ...
    def is_number(self) -> bool: ...
    def is_object(self) -> bool: ...
    def is_string(self) -> bool: ...
    def is_typed_array(self) -> bool: ...
    def is_undefined(self) -> bool: ...
    @classmethod
    def new_array_buffer(
        cls,
        context: Context,
        data: None,
        size: int,
        destroy_notify: Optional[Callable[..., None]] = None,
        *user_data: Any,
    ) -> Optional[Value]: ...
    @classmethod
    def new_array_from_garray(
        cls, context: Context, array: Optional[Sequence[Value]] = None
    ) -> Value: ...
    @classmethod
    def new_array_from_strv(cls, context: Context, strv: Sequence[str]) -> Value: ...
    @classmethod
    def new_boolean(cls, context: Context, value: bool) -> Value: ...
    @classmethod
    def new_from_json(cls, context: Context, json: str) -> Value: ...
    @classmethod
    def new_function(
        cls,
        context: Context,
        name: Optional[str],
        callback: Callable[..., None],
        return_type: Type,
        parameter_types: Optional[Sequence[Type]] = None,
        *user_data: Any,
    ) -> Value: ...
    @classmethod
    def new_function_variadic(
        cls,
        context: Context,
        name: Optional[str],
        callback: Callable[..., None],
        return_type: Type,
        *user_data: Any,
    ) -> Value: ...
    @classmethod
    def new_null(cls, context: Context) -> Value: ...
    @classmethod
    def new_number(cls, context: Context, number: float) -> Value: ...
    @classmethod
    def new_object(
        cls, context: Context, instance: None, jsc_class: Optional[Class] = None
    ) -> Value: ...
    @classmethod
    def new_string(cls, context: Context, string: Optional[str] = None) -> Value: ...
    @classmethod
    def new_string_from_bytes(
        cls, context: Context, bytes: Optional[GLib.Bytes] = None
    ) -> Value: ...
    @classmethod
    def new_typed_array(
        cls, context: Context, type: TypedArrayType, length: int
    ) -> Value: ...
    def new_typed_array_with_buffer(
        self, type: TypedArrayType, offset: int, length: int
    ) -> Value: ...
    @classmethod
    def new_undefined(cls, context: Context) -> Value: ...
    def object_define_property_accessor(
        self,
        property_name: str,
        flags: ValuePropertyFlags,
        property_type: Type,
        getter: Optional[Callable[..., None]] = None,
        setter: Optional[Callable[..., None]] = None,
        *user_data: Any,
    ) -> None: ...
    def object_define_property_data(
        self,
        property_name: str,
        flags: ValuePropertyFlags,
        property_value: Optional[Value] = None,
    ) -> None: ...
    def object_delete_property(self, name: str) -> bool: ...
    def object_enumerate_properties(self) -> Optional[list[str]]: ...
    def object_get_property(self, name: str) -> Value: ...
    def object_get_property_at_index(self, index: int) -> Value: ...
    def object_has_property(self, name: str) -> bool: ...
    def object_invoke_method(
        self, name: str, parameters: Optional[Sequence[Value]] = None
    ) -> Value: ...
    def object_is_instance_of(self, name: str) -> bool: ...
    def object_set_property(self, name: str, property: Value) -> None: ...
    def object_set_property_at_index(self, index: int, property: Value) -> None: ...
    def to_boolean(self) -> bool: ...
    def to_double(self) -> float: ...
    def to_int32(self) -> int: ...
    def to_json(self, indent: int) -> str: ...
    def to_string(self) -> str: ...
    def to_string_as_bytes(self) -> GLib.Bytes: ...
    def typed_array_get_buffer(self) -> Value: ...
    def typed_array_get_data(self) -> int: ...
    def typed_array_get_length(self) -> int: ...
    def typed_array_get_offset(self) -> int: ...
    def typed_array_get_size(self) -> int: ...
    def typed_array_get_type(self) -> TypedArrayType: ...

class ValueClass(GObject.GPointer):
    """
    :Constructors:

    ::

        ValueClass()
    """

    parent_class: GObject.ObjectClass = ...

class VirtualMachine(GObject.Object):
    """
    :Constructors:

    ::

        VirtualMachine(**properties)
        new() -> JavaScriptCore.VirtualMachine

    Object JSCVirtualMachine

    Signals from GObject:
      notify (GParam)
    """

    @classmethod
    def new(cls) -> VirtualMachine: ...

class VirtualMachineClass(GObject.GPointer):
    """
    :Constructors:

    ::

        VirtualMachineClass()
    """

    parent_class: GObject.ObjectClass = ...

class WeakValue(GObject.Object):
    """
    :Constructors:

    ::

        WeakValue(**properties)
        new(value:JavaScriptCore.Value) -> JavaScriptCore.WeakValue

    Object JSCWeakValue

    Signals from JSCWeakValue:
      cleared ()

    Properties from JSCWeakValue:
      value -> JSCValue: value

    Signals from GObject:
      notify (GParam)
    """

    class Props:
        value: Value

    props: Props = ...
    def __init__(self, value: Value = ...): ...
    def get_value(self) -> Value: ...
    @classmethod
    def new(cls, value: Value) -> WeakValue: ...

class WeakValueClass(GObject.GPointer):
    """
    :Constructors:

    ::

        WeakValueClass()
    """

    parent_class: GObject.ObjectClass = ...

class ValuePropertyFlags(GObject.GFlags):
    CONFIGURABLE = 1
    ENUMERABLE = 2
    WRITABLE = 4

class CheckSyntaxMode(GObject.GEnum):
    MODULE = 1
    SCRIPT = 0

class CheckSyntaxResult(GObject.GEnum):
    IRRECOVERABLE_ERROR = 2
    OUT_OF_MEMORY_ERROR = 4
    RECOVERABLE_ERROR = 1
    STACK_OVERFLOW_ERROR = 5
    SUCCESS = 0
    UNTERMINATED_LITERAL_ERROR = 3

class OptionType(GObject.GEnum):
    BOOLEAN = 0
    DOUBLE = 4
    INT = 1
    RANGE_STRING = 6
    SIZE = 3
    STRING = 5
    UINT = 2

class TypedArrayType(GObject.GEnum):
    FLOAT32 = 10
    FLOAT64 = 11
    INT16 = 2
    INT32 = 3
    INT64 = 4
    INT8 = 1
    NONE = 0
    UINT16 = 7
    UINT32 = 8
    UINT64 = 9
    UINT8 = 5
    UINT8_CLAMPED = 6



import typing

from gi.repository import GObject
from typing_extensions import Self

T = typing.TypeVar("T")

class Connection(GObject.GPointer): ...
class MethodInvocation(GObject.GPointer): ...
class Proxy(GObject.Object): ...
class ProxyClass(GObject.GPointer): ...



import typing

from gi.repository import Gio
from gi.repository import GLib
from gi.repository import GObject
from gi.repository import Gst
from gi.repository import GstSdp
from typing_extensions import Self

T = typing.TypeVar("T")

RTSP_DEFAULT_PORT: int = 554

def rtsp_auth_credentials_free(credentials: RTSPAuthCredential) -> None: ...
def rtsp_connection_accept(
    socket: Gio.Socket, cancellable: typing.Optional[Gio.Cancellable] = None
) -> typing.Tuple[RTSPResult, RTSPConnection]: ...
def rtsp_connection_create(
    url: RTSPUrl,
) -> typing.Tuple[RTSPResult, RTSPConnection]: ...
def rtsp_connection_create_from_socket(
    socket: Gio.Socket, ip: str, port: int, initial_buffer: str
) -> typing.Tuple[RTSPResult, RTSPConnection]: ...
def rtsp_find_header_field(header: str) -> RTSPHeaderField: ...
def rtsp_find_method(method: str) -> RTSPMethod: ...
def rtsp_generate_digest_auth_response(
    algorithm: typing.Optional[str],
    method: str,
    realm: str,
    username: str,
    password: str,
    uri: str,
    nonce: str,
) -> typing.Optional[str]: ...
def rtsp_generate_digest_auth_response_from_md5(
    algorithm: typing.Optional[str], method: str, md5: str, uri: str, nonce: str
) -> typing.Optional[str]: ...
def rtsp_header_allow_multiple(field: RTSPHeaderField) -> bool: ...
def rtsp_header_as_text(field: RTSPHeaderField) -> typing.Optional[str]: ...
def rtsp_message_new() -> typing.Tuple[RTSPResult, RTSPMessage]: ...
def rtsp_message_new_data(channel: int) -> typing.Tuple[RTSPResult, RTSPMessage]: ...
def rtsp_message_new_request(
    method: RTSPMethod, uri: str
) -> typing.Tuple[RTSPResult, RTSPMessage]: ...
def rtsp_message_new_response(
    code: RTSPStatusCode,
    reason: typing.Optional[str] = None,
    request: typing.Optional[RTSPMessage] = None,
) -> typing.Tuple[RTSPResult, RTSPMessage]: ...
def rtsp_method_as_text(method: RTSPMethod) -> typing.Optional[str]: ...
def rtsp_options_as_text(options: RTSPMethod) -> str: ...
def rtsp_options_from_text(options: str) -> RTSPMethod: ...
def rtsp_range_convert_units(range: RTSPTimeRange, unit: RTSPRangeUnit) -> bool: ...
def rtsp_range_free(range: RTSPTimeRange) -> None: ...
def rtsp_range_get_times(range: RTSPTimeRange) -> typing.Tuple[bool, int, int]: ...
def rtsp_range_parse(rangestr: str) -> typing.Tuple[RTSPResult, RTSPTimeRange]: ...
def rtsp_range_to_string(range: RTSPTimeRange) -> str: ...
def rtsp_status_as_text(code: RTSPStatusCode) -> str: ...
def rtsp_strresult(result: RTSPResult) -> str: ...
def rtsp_transport_get_manager(
    trans: RTSPTransMode, option: int
) -> typing.Tuple[RTSPResult, str]: ...
def rtsp_transport_get_mime(trans: RTSPTransMode) -> typing.Tuple[RTSPResult, str]: ...
def rtsp_transport_init() -> typing.Tuple[RTSPResult, RTSPTransport]: ...
def rtsp_transport_new() -> typing.Tuple[RTSPResult, RTSPTransport]: ...
def rtsp_transport_parse(str: str) -> typing.Tuple[RTSPResult, RTSPTransport]: ...
def rtsp_url_parse(urlstr: str) -> typing.Tuple[RTSPResult, RTSPUrl]: ...
def rtsp_version_as_text(version: RTSPVersion) -> str: ...

class RTSPAuthCredential(GObject.GBoxed):
    """
    :Constructors:

    ::

        RTSPAuthCredential()
    """

    scheme: RTSPAuthMethod = ...
    params: RTSPAuthParam = ...
    authorization: str = ...

class RTSPAuthParam(GObject.GBoxed):
    """
    :Constructors:

    ::

        RTSPAuthParam()
    """

    name: str = ...
    value: str = ...
    def copy(self) -> RTSPAuthParam: ...
    def free(self) -> None: ...

class RTSPConnection(GObject.GPointer):
    @staticmethod
    def accept(
        socket: Gio.Socket, cancellable: typing.Optional[Gio.Cancellable] = None
    ) -> typing.Tuple[RTSPResult, RTSPConnection]: ...
    def add_extra_http_request_header(self, key: str, value: str) -> None: ...
    def clear_auth_params(self) -> None: ...
    def close(self) -> RTSPResult: ...
    def connect(self, timeout: GLib.TimeVal) -> RTSPResult: ...
    def connect_usec(self, timeout: int) -> RTSPResult: ...
    def connect_with_response(
        self, timeout: GLib.TimeVal, response: RTSPMessage
    ) -> RTSPResult: ...
    def connect_with_response_usec(
        self, timeout: int, response: RTSPMessage
    ) -> RTSPResult: ...
    @staticmethod
    def create(url: RTSPUrl) -> typing.Tuple[RTSPResult, RTSPConnection]: ...
    @staticmethod
    def create_from_socket(
        socket: Gio.Socket, ip: str, port: int, initial_buffer: str
    ) -> typing.Tuple[RTSPResult, RTSPConnection]: ...
    def do_tunnel(
        self, conn2: typing.Optional[RTSPConnection] = None
    ) -> RTSPResult: ...
    def flush(self, flush: bool) -> RTSPResult: ...
    def free(self) -> RTSPResult: ...
    def get_ignore_x_server_reply(self) -> bool: ...
    def get_ip(self) -> typing.Optional[str]: ...
    def get_read_socket(self) -> typing.Optional[Gio.Socket]: ...
    def get_remember_session_id(self) -> bool: ...
    def get_tls(self) -> Gio.TlsConnection: ...
    def get_tls_database(self) -> typing.Optional[Gio.TlsDatabase]: ...
    def get_tls_interaction(self) -> typing.Optional[Gio.TlsInteraction]: ...
    def get_tls_validation_flags(self) -> Gio.TlsCertificateFlags: ...
    def get_tunnelid(self) -> typing.Optional[str]: ...
    def get_url(self) -> RTSPUrl: ...
    def get_write_socket(self) -> typing.Optional[Gio.Socket]: ...
    def is_tunneled(self) -> bool: ...
    def next_timeout(self, timeout: GLib.TimeVal) -> RTSPResult: ...
    def next_timeout_usec(self) -> int: ...
    def poll(
        self, events: RTSPEvent, timeout: GLib.TimeVal
    ) -> typing.Tuple[RTSPResult, RTSPEvent]: ...
    def poll_usec(
        self, events: RTSPEvent, timeout: int
    ) -> typing.Tuple[RTSPResult, RTSPEvent]: ...
    def read(self, data: typing.Sequence[int], timeout: GLib.TimeVal) -> RTSPResult: ...
    def read_usec(self, data: typing.Sequence[int], timeout: int) -> RTSPResult: ...
    def receive(self, message: RTSPMessage, timeout: GLib.TimeVal) -> RTSPResult: ...
    def receive_usec(self, message: RTSPMessage, timeout: int) -> RTSPResult: ...
    def reset_timeout(self) -> RTSPResult: ...
    def send(self, message: RTSPMessage, timeout: GLib.TimeVal) -> RTSPResult: ...
    def send_messages(
        self, messages: typing.Sequence[RTSPMessage], timeout: GLib.TimeVal
    ) -> RTSPResult: ...
    def send_messages_usec(
        self, messages: typing.Sequence[RTSPMessage], timeout: int
    ) -> RTSPResult: ...
    def send_usec(self, message: RTSPMessage, timeout: int) -> RTSPResult: ...
    def set_accept_certificate_func(
        self, func: typing.Callable[..., bool], *user_data: typing.Any
    ) -> None: ...
    def set_auth(self, method: RTSPAuthMethod, user: str, pass_: str) -> RTSPResult: ...
    def set_auth_param(self, param: str, value: str) -> None: ...
    def set_content_length_limit(self, limit: int) -> None: ...
    def set_http_mode(self, enable: bool) -> None: ...
    def set_ignore_x_server_reply(self, ignore: bool) -> None: ...
    def set_ip(self, ip: str) -> None: ...
    def set_proxy(self, host: str, port: int) -> RTSPResult: ...
    def set_qos_dscp(self, qos_dscp: int) -> RTSPResult: ...
    def set_remember_session_id(self, remember: bool) -> None: ...
    def set_tls_database(
        self, database: typing.Optional[Gio.TlsDatabase] = None
    ) -> None: ...
    def set_tls_interaction(
        self, interaction: typing.Optional[Gio.TlsInteraction] = None
    ) -> None: ...
    def set_tls_validation_flags(self, flags: Gio.TlsCertificateFlags) -> bool: ...
    def set_tunneled(self, tunneled: bool) -> None: ...
    def write(
        self, data: typing.Sequence[int], timeout: GLib.TimeVal
    ) -> RTSPResult: ...
    def write_usec(self, data: typing.Sequence[int], timeout: int) -> RTSPResult: ...

class RTSPExtension(GObject.GInterface):
    """
    Interface GstRTSPExtension
    """
    def after_send(self, req: RTSPMessage, resp: RTSPMessage) -> RTSPResult: ...
    def before_send(self, req: RTSPMessage) -> RTSPResult: ...
    def configure_stream(self, caps: Gst.Caps) -> bool: ...
    def detect_server(self, resp: RTSPMessage) -> bool: ...
    def get_transports(
        self, protocols: RTSPLowerTrans, transport: str
    ) -> RTSPResult: ...
    def parse_sdp(self, sdp: GstSdp.SDPMessage, s: Gst.Structure) -> RTSPResult: ...
    def receive_request(self, req: RTSPMessage) -> RTSPResult: ...
    def send(self, req: RTSPMessage, resp: RTSPMessage) -> RTSPResult: ...
    def setup_media(self, media: GstSdp.SDPMedia) -> RTSPResult: ...
    def stream_select(self, url: RTSPUrl) -> RTSPResult: ...

class RTSPExtensionInterface(GObject.GPointer):
    """
    :Constructors:

    ::

        RTSPExtensionInterface()
    """

    parent: GObject.TypeInterface = ...
    detect_server: typing.Callable[[RTSPExtension, RTSPMessage], bool] = ...
    before_send: typing.Callable[[RTSPExtension, RTSPMessage], RTSPResult] = ...
    after_send: typing.Callable[
        [RTSPExtension, RTSPMessage, RTSPMessage], RTSPResult
    ] = ...
    parse_sdp: typing.Callable[
        [RTSPExtension, GstSdp.SDPMessage, Gst.Structure], RTSPResult
    ] = ...
    setup_media: typing.Callable[[RTSPExtension, GstSdp.SDPMedia], RTSPResult] = ...
    configure_stream: typing.Callable[[RTSPExtension, Gst.Caps], bool] = ...
    get_transports: typing.Callable[
        [RTSPExtension, RTSPLowerTrans, str], RTSPResult
    ] = ...
    stream_select: typing.Callable[[RTSPExtension, RTSPUrl], RTSPResult] = ...
    send: typing.Callable[[RTSPExtension, RTSPMessage, RTSPMessage], RTSPResult] = ...
    receive_request: typing.Callable[[RTSPExtension, RTSPMessage], RTSPResult] = ...

class RTSPMessage(GObject.GBoxed):
    """
    :Constructors:

    ::

        RTSPMessage()
    """

    type: RTSPMsgType = ...
    hdr_fields: list[None] = ...
    body: int = ...
    body_size: int = ...
    body_buffer: Gst.Buffer = ...
    def add_header(self, field: RTSPHeaderField, value: str) -> RTSPResult: ...
    def add_header_by_name(self, header: str, value: str) -> RTSPResult: ...
    def append_headers(self, str: GLib.String) -> RTSPResult: ...
    def copy(self) -> typing.Tuple[RTSPResult, RTSPMessage]: ...
    def dump(self) -> RTSPResult: ...
    def free(self) -> RTSPResult: ...
    def get_body(self) -> typing.Tuple[RTSPResult, bytes]: ...
    def get_body_buffer(self) -> typing.Tuple[RTSPResult, Gst.Buffer]: ...
    def get_header(
        self, field: RTSPHeaderField, indx: int
    ) -> typing.Tuple[RTSPResult, str]: ...
    def get_header_by_name(
        self, header: str, index: int
    ) -> typing.Tuple[RTSPResult, str]: ...
    def get_type(self) -> RTSPMsgType: ...
    def has_body_buffer(self) -> bool: ...
    def init(self) -> RTSPResult: ...
    def init_data(self, channel: int) -> RTSPResult: ...
    def init_request(self, method: RTSPMethod, uri: str) -> RTSPResult: ...
    def init_response(
        self,
        code: RTSPStatusCode,
        reason: typing.Optional[str] = None,
        request: typing.Optional[RTSPMessage] = None,
    ) -> RTSPResult: ...
    def parse_auth_credentials(
        self, field: RTSPHeaderField
    ) -> list[RTSPAuthCredential]: ...
    def parse_data(self) -> typing.Tuple[RTSPResult, int]: ...
    def parse_request(
        self,
    ) -> typing.Tuple[RTSPResult, RTSPMethod, str, RTSPVersion]: ...
    def parse_response(
        self,
    ) -> typing.Tuple[RTSPResult, RTSPStatusCode, str, RTSPVersion]: ...
    def remove_header(self, field: RTSPHeaderField, indx: int) -> RTSPResult: ...
    def remove_header_by_name(self, header: str, index: int) -> RTSPResult: ...
    def set_body(self, data: typing.Sequence[int]) -> RTSPResult: ...
    def set_body_buffer(self, buffer: Gst.Buffer) -> RTSPResult: ...
    def steal_body(self) -> typing.Tuple[RTSPResult, bytes]: ...
    def steal_body_buffer(self) -> typing.Tuple[RTSPResult, Gst.Buffer]: ...
    def take_body(self, data: typing.Sequence[int]) -> RTSPResult: ...
    def take_body_buffer(self, buffer: Gst.Buffer) -> RTSPResult: ...
    def take_header(self, field: RTSPHeaderField, value: str) -> RTSPResult: ...
    def take_header_by_name(self, header: str, value: str) -> RTSPResult: ...
    def unset(self) -> RTSPResult: ...

class RTSPRange(GObject.GPointer):
    """
    :Constructors:

    ::

        RTSPRange()
    """

    min: int = ...
    max: int = ...
    @staticmethod
    def convert_units(range: RTSPTimeRange, unit: RTSPRangeUnit) -> bool: ...
    @staticmethod
    def free(range: RTSPTimeRange) -> None: ...
    @staticmethod
    def get_times(range: RTSPTimeRange) -> typing.Tuple[bool, int, int]: ...
    @staticmethod
    def parse(rangestr: str) -> typing.Tuple[RTSPResult, RTSPTimeRange]: ...
    @staticmethod
    def to_string(range: RTSPTimeRange) -> str: ...

class RTSPTime(GObject.GPointer):
    """
    :Constructors:

    ::

        RTSPTime()
    """

    type: RTSPTimeType = ...
    seconds: float = ...

class RTSPTime2(GObject.GPointer):
    """
    :Constructors:

    ::

        RTSPTime2()
    """

    frames: float = ...
    year: int = ...
    month: int = ...
    day: int = ...

class RTSPTimeRange(GObject.GPointer):
    """
    :Constructors:

    ::

        RTSPTimeRange()
    """

    unit: RTSPRangeUnit = ...
    min: RTSPTime = ...
    max: RTSPTime = ...
    min2: RTSPTime2 = ...
    max2: RTSPTime2 = ...

class RTSPTransport(GObject.GPointer):
    """
    :Constructors:

    ::

        RTSPTransport()
    """

    trans: RTSPTransMode = ...
    profile: RTSPProfile = ...
    lower_transport: RTSPLowerTrans = ...
    destination: str = ...
    source: str = ...
    layers: int = ...
    mode_play: bool = ...
    mode_record: bool = ...
    append: bool = ...
    interleaved: RTSPRange = ...
    ttl: int = ...
    port: RTSPRange = ...
    client_port: RTSPRange = ...
    server_port: RTSPRange = ...
    ssrc: int = ...
    def as_text(self) -> typing.Optional[str]: ...
    def free(self) -> RTSPResult: ...
    @staticmethod
    def get_manager(
        trans: RTSPTransMode, option: int
    ) -> typing.Tuple[RTSPResult, str]: ...
    def get_media_type(self) -> typing.Tuple[RTSPResult, str]: ...
    @staticmethod
    def get_mime(trans: RTSPTransMode) -> typing.Tuple[RTSPResult, str]: ...
    @staticmethod
    def init() -> typing.Tuple[RTSPResult, RTSPTransport]: ...
    @staticmethod
    def new() -> typing.Tuple[RTSPResult, RTSPTransport]: ...
    @staticmethod
    def parse(str: str) -> typing.Tuple[RTSPResult, RTSPTransport]: ...

class RTSPUrl(GObject.GBoxed):
    """
    :Constructors:

    ::

        RTSPUrl()
    """

    transports: RTSPLowerTrans = ...
    family: RTSPFamily = ...
    user: str = ...
    passwd: str = ...
    host: str = ...
    port: int = ...
    abspath: str = ...
    query: str = ...
    def copy(self) -> RTSPUrl: ...
    def decode_path_components(self) -> list[str]: ...
    def free(self) -> None: ...
    def get_port(self) -> typing.Tuple[RTSPResult, int]: ...
    def get_request_uri(self) -> str: ...
    def get_request_uri_with_control(self, control_path: str) -> str: ...
    @staticmethod
    def parse(urlstr: str) -> typing.Tuple[RTSPResult, RTSPUrl]: ...
    def set_port(self, port: int) -> RTSPResult: ...

class RTSPWatch(GObject.GPointer):
    def attach(self, context: typing.Optional[GLib.MainContext] = None) -> int: ...
    def get_send_backlog(self) -> typing.Tuple[int, int]: ...
    def reset(self) -> None: ...
    def send_message(self, message: RTSPMessage) -> typing.Tuple[RTSPResult, int]: ...
    def send_messages(
        self, messages: typing.Sequence[RTSPMessage]
    ) -> typing.Tuple[RTSPResult, int]: ...
    def set_flushing(self, flushing: bool) -> None: ...
    def set_send_backlog(self, bytes: int, messages: int) -> None: ...
    def unref(self) -> None: ...
    def wait_backlog(self, timeout: GLib.TimeVal) -> RTSPResult: ...
    def wait_backlog_usec(self, timeout: int) -> RTSPResult: ...
    def write_data(
        self, data: typing.Sequence[int]
    ) -> typing.Tuple[RTSPResult, int]: ...

class RTSPWatchFuncs(GObject.GPointer):
    """
    :Constructors:

    ::

        RTSPWatchFuncs()
    """

    message_received: typing.Callable[..., RTSPResult] = ...
    message_sent: typing.Callable[..., RTSPResult] = ...
    closed: typing.Callable[..., RTSPResult] = ...
    error: typing.Callable[..., RTSPResult] = ...
    tunnel_start: typing.Callable[..., RTSPStatusCode] = ...
    tunnel_complete: typing.Callable[..., RTSPResult] = ...
    error_full: typing.Callable[..., RTSPResult] = ...
    tunnel_lost: typing.Callable[..., RTSPResult] = ...
    tunnel_http_response: typing.Callable[..., RTSPResult] = ...

class RTSPEvent(GObject.GFlags):
    READ = 1
    WRITE = 2

class RTSPLowerTrans(GObject.GFlags):
    HTTP = 16
    TCP = 4
    TLS = 32
    UDP = 1
    UDP_MCAST = 2
    UNKNOWN = 0

class RTSPMethod(GObject.GFlags):
    ANNOUNCE = 2
    DESCRIBE = 1
    GET = 2048
    GET_PARAMETER = 4
    INVALID = 0
    OPTIONS = 8
    PAUSE = 16
    PLAY = 32
    POST = 4096
    RECORD = 64
    REDIRECT = 128
    SETUP = 256
    SET_PARAMETER = 512
    TEARDOWN = 1024
    @staticmethod
    def as_text(method: RTSPMethod) -> typing.Optional[str]: ...

class RTSPProfile(GObject.GFlags):
    AVP = 1
    AVPF = 4
    SAVP = 2
    SAVPF = 8
    UNKNOWN = 0

class RTSPTransMode(GObject.GFlags):
    RDT = 2
    RTP = 1
    UNKNOWN = 0

class RTSPAuthMethod(GObject.GEnum):
    BASIC = 1
    DIGEST = 2
    NONE = 0

class RTSPFamily(GObject.GEnum):
    INET = 1
    INET6 = 2
    NONE = 0

class RTSPHeaderField(GObject.GEnum):
    ACCEPT = 1
    ACCEPT_CHARSET = 56
    ACCEPT_ENCODING = 2
    ACCEPT_LANGUAGE = 3
    ACCEPT_RANGES = 86
    ALERT = 45
    ALLOW = 4
    AUTHENTICATION_INFO = 76
    AUTHORIZATION = 5
    BANDWIDTH = 6
    BLOCKSIZE = 7
    CACHE_CONTROL = 8
    CLIENT_CHALLENGE = 40
    CLIENT_ID = 46
    COMPANY_ID = 47
    CONFERENCE = 9
    CONNECTION = 10
    CONTENT_BASE = 11
    CONTENT_ENCODING = 12
    CONTENT_LANGUAGE = 13
    CONTENT_LENGTH = 14
    CONTENT_LOCATION = 15
    CONTENT_TYPE = 16
    CSEQ = 17
    DATE = 18
    ETAG = 54
    EXPIRES = 19
    FRAMES = 87
    FROM = 20
    GUID = 48
    HOST = 77
    IF_MATCH = 55
    IF_MODIFIED_SINCE = 21
    INVALID = 0
    KEYMGMT = 82
    LANGUAGE = 51
    LAST = 89
    LAST_MODIFIED = 22
    LOCATION = 53
    MAX_ASM_WIDTH = 50
    MEDIA_PROPERTIES = 84
    PIPELINED_REQUESTS = 83
    PLAYER_START_TIME = 52
    PRAGMA = 78
    PROXY_AUTHENTICATE = 23
    PROXY_REQUIRE = 24
    PUBLIC = 25
    RANGE = 26
    RATE_CONTROL = 88
    REAL_CHALLENGE1 = 41
    REAL_CHALLENGE2 = 42
    REAL_CHALLENGE3 = 43
    REFERER = 27
    REGION_DATA = 49
    REQUIRE = 28
    RETRY_AFTER = 29
    RTCP_INTERVAL = 81
    RTP_INFO = 30
    SCALE = 31
    SEEK_STYLE = 85
    SERVER = 33
    SESSION = 32
    SPEED = 34
    SUBSCRIBE = 44
    SUPPORTED = 57
    TIMESTAMP = 75
    TRANSPORT = 35
    UNSUPPORTED = 36
    USER_AGENT = 37
    VARY = 58
    VIA = 38
    WWW_AUTHENTICATE = 39
    X_ACCELERATE_STREAMING = 59
    X_ACCEPT_AUTHENT = 60
    X_ACCEPT_PROXY_AUTHENT = 61
    X_BROADCAST_ID = 62
    X_BURST_STREAMING = 63
    X_NOTICE = 64
    X_PLAYER_LAG_TIME = 65
    X_PLAYLIST = 66
    X_PLAYLIST_CHANGE_NOTICE = 67
    X_PLAYLIST_GEN_ID = 68
    X_PLAYLIST_SEEK_ID = 69
    X_PROXY_CLIENT_AGENT = 70
    X_PROXY_CLIENT_VERB = 71
    X_RECEDING_PLAYLISTCHANGE = 72
    X_RTP_INFO = 73
    X_SERVER_IP_ADDRESS = 79
    X_SESSIONCOOKIE = 80
    X_STARTUPPROFILE = 74

class RTSPMsgType(GObject.GEnum):
    DATA = 5
    HTTP_REQUEST = 3
    HTTP_RESPONSE = 4
    INVALID = 0
    REQUEST = 1
    RESPONSE = 2

class RTSPRangeUnit(GObject.GEnum):
    CLOCK = 4
    NPT = 3
    SMPTE = 0
    SMPTE_25 = 2
    SMPTE_30_DROP = 1

class RTSPResult(GObject.GEnum):
    EEOF = -11
    EINTR = -3
    EINVAL = -2
    ELAST = -17
    ENET = -12
    ENOMEM = -4
    ENOTIMPL = -6
    ENOTIP = -13
    EPARSE = -8
    ERESOLV = -5
    ERROR = -1
    ESYS = -7
    ETGET = -15
    ETIMEOUT = -14
    ETPOST = -16
    EWSASTART = -9
    EWSAVERSION = -10
    OK = 0
    OK_REDIRECT = 1

class RTSPState(GObject.GEnum):
    INIT = 1
    INVALID = 0
    PLAYING = 4
    READY = 2
    RECORDING = 5
    SEEKING = 3

class RTSPStatusCode(GObject.GEnum):
    AGGREGATE_OPERATION_NOT_ALLOWED = 459
    BAD_GATEWAY = 502
    BAD_REQUEST = 400
    CONFERENCE_NOT_FOUND = 452
    CONTINUE = 100
    CREATED = 201
    DESTINATION_UNREACHABLE = 462
    FORBIDDEN = 403
    GATEWAY_TIMEOUT = 504
    GONE = 410
    HEADER_FIELD_NOT_VALID_FOR_RESOURCE = 456
    INTERNAL_SERVER_ERROR = 500
    INVALID = 0
    INVALID_RANGE = 457
    KEY_MANAGEMENT_FAILURE = 463
    LENGTH_REQUIRED = 411
    LOW_ON_STORAGE = 250
    METHOD_NOT_ALLOWED = 405
    METHOD_NOT_VALID_IN_THIS_STATE = 455
    MOVED_PERMANENTLY = 301
    MOVE_TEMPORARILY = 302
    MULTIPLE_CHOICES = 300
    NOT_ACCEPTABLE = 406
    NOT_ENOUGH_BANDWIDTH = 453
    NOT_FOUND = 404
    NOT_IMPLEMENTED = 501
    NOT_MODIFIED = 304
    OK = 200
    ONLY_AGGREGATE_OPERATION_ALLOWED = 460
    OPTION_NOT_SUPPORTED = 551
    PARAMETER_IS_READONLY = 458
    PARAMETER_NOT_UNDERSTOOD = 451
    PAYMENT_REQUIRED = 402
    PRECONDITION_FAILED = 412
    PROXY_AUTH_REQUIRED = 407
    REDIRECT_PERMANENTLY = 308
    REDIRECT_TEMPORARILY = 307
    REQUEST_ENTITY_TOO_LARGE = 413
    REQUEST_TIMEOUT = 408
    REQUEST_URI_TOO_LARGE = 414
    RTSP_VERSION_NOT_SUPPORTED = 505
    SEE_OTHER = 303
    SERVICE_UNAVAILABLE = 503
    SESSION_NOT_FOUND = 454
    UNAUTHORIZED = 401
    UNSUPPORTED_MEDIA_TYPE = 415
    UNSUPPORTED_TRANSPORT = 461
    USE_PROXY = 305

class RTSPTimeType(GObject.GEnum):
    END = 2
    FRAMES = 3
    NOW = 1
    SECONDS = 0
    UTC = 4

class RTSPVersion(GObject.GEnum):
    INVALID = 0
    @staticmethod
    def as_text(version: RTSPVersion) -> str: ...
